Class: Google::Cloud::Container::V1::AdditionalIPRangesConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AdditionalIPRangesConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
AdditionalIPRangesConfig is the configuration for individual additional subnetwork attached to the cluster
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#pod_ipv4_range_names ⇒ ::Array<::String>
List of secondary ranges names within this subnetwork that can be used for pod IPs.
-
#status ⇒ ::Google::Cloud::Container::V1::AdditionalIPRangesConfig::Status
Draining status of the additional subnet.
-
#subnetwork ⇒ ::String
Name of the subnetwork.
Instance Attribute Details
#pod_ipv4_range_names ⇒ ::Array<::String>
Returns List of secondary ranges names within this subnetwork that can be used for pod IPs. Example1: gke-pod-range1 Example2: gke-pod-range1,gke-pod-range2.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3698 class AdditionalIPRangesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional subnet with DRAINING status will not be selected during new node # pool creation. To undrain the draining status, update the cluster to set # the subnet to ACTIVE status. To remove the additional subnet, use the # update cluster API to remove the subnet from the # desired_additional_ip_ranges list. IP ranges can be removed regardless of # its status, as long as no node pools are using them. module Status # Not set, same as ACTIVE. STATUS_UNSPECIFIED = 0 # ACTIVE status indicates that the subnet is available for new node pool # creation. ACTIVE = 1 # DRAINING status indicates that the subnet is not used for new node pool # creation. DRAINING = 2 end end |
#status ⇒ ::Google::Cloud::Container::V1::AdditionalIPRangesConfig::Status
Returns Draining status of the additional subnet.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3698 class AdditionalIPRangesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional subnet with DRAINING status will not be selected during new node # pool creation. To undrain the draining status, update the cluster to set # the subnet to ACTIVE status. To remove the additional subnet, use the # update cluster API to remove the subnet from the # desired_additional_ip_ranges list. IP ranges can be removed regardless of # its status, as long as no node pools are using them. module Status # Not set, same as ACTIVE. STATUS_UNSPECIFIED = 0 # ACTIVE status indicates that the subnet is available for new node pool # creation. ACTIVE = 1 # DRAINING status indicates that the subnet is not used for new node pool # creation. DRAINING = 2 end end |
#subnetwork ⇒ ::String
Returns Name of the subnetwork. This can be the full path of the subnetwork or just the name. Example1: my-subnet Example2: projects/gke-project/regions/us-central1/subnetworks/my-subnet.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3698 class AdditionalIPRangesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional subnet with DRAINING status will not be selected during new node # pool creation. To undrain the draining status, update the cluster to set # the subnet to ACTIVE status. To remove the additional subnet, use the # update cluster API to remove the subnet from the # desired_additional_ip_ranges list. IP ranges can be removed regardless of # its status, as long as no node pools are using them. module Status # Not set, same as ACTIVE. STATUS_UNSPECIFIED = 0 # ACTIVE status indicates that the subnet is available for new node pool # creation. ACTIVE = 1 # DRAINING status indicates that the subnet is not used for new node pool # creation. DRAINING = 2 end end |