Module: Google::Cloud::Container::V1::AdditionalIPRangesConfig::Status

Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Additional subnet with DRAINING status will not be selected during new node pool creation. To undrain the draining status, update the cluster to set the sunbet to ACTIVE status. To remove the additional subnet, use the update cluster API to remove the subnet from the desired_additional_ip_ranges list. IP ranges can be removed regardless of its status, as long as no node pools are using them.

Constant Summary collapse

STATUS_UNSPECIFIED =

Not set, same as ACTIVE.

0
ACTIVE =

ACTIVE status indicates that the subnet is available for new node pool creation.

1
DRAINING =

DRAINING status indicates that the subnet is not used for new node pool creation.

2