Class: Google::Cloud::Container::V1::AddonsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AddonsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
Instance Attribute Summary collapse
-
#cloud_run_config ⇒ ::Google::Cloud::Container::V1::CloudRunConfig
Configuration for the Cloud Run addon, which allows the user to use a managed Knative service.
-
#config_connector_config ⇒ ::Google::Cloud::Container::V1::ConfigConnectorConfig
Configuration for the ConfigConnector add-on, a Kubernetes extension to manage hosted Google Cloud services through the Kubernetes API.
-
#dns_cache_config ⇒ ::Google::Cloud::Container::V1::DnsCacheConfig
Configuration for NodeLocalDNS, a dns cache running on cluster nodes.
-
#gce_persistent_disk_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine Persistent Disk CSI driver.
-
#gcp_filestore_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
-
#gcs_fuse_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
-
#gke_backup_agent_config ⇒ ::Google::Cloud::Container::V1::GkeBackupAgentConfig
Configuration for the Backup for GKE agent addon.
-
#high_scale_checkpointing_config ⇒ ::Google::Cloud::Container::V1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing add-on.
-
#horizontal_pod_autoscaling ⇒ ::Google::Cloud::Container::V1::HorizontalPodAutoscaling
Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
-
#http_load_balancing ⇒ ::Google::Cloud::Container::V1::HttpLoadBalancing
Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
-
#kubernetes_dashboard ⇒ ::Google::Cloud::Container::V1::KubernetesDashboard
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#lustre_csi_driver_config ⇒ ::Google::Cloud::Container::V1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
-
#network_policy_config ⇒ ::Google::Cloud::Container::V1::NetworkPolicyConfig
Configuration for NetworkPolicy.
-
#parallelstore_csi_driver_config ⇒ ::Google::Cloud::Container::V1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
-
#ray_operator_config ⇒ ::Google::Cloud::Container::V1::RayOperatorConfig
Optional.
-
#slice_controller_config ⇒ ::Google::Cloud::Container::V1::SliceControllerConfig
Optional.
-
#stateful_ha_config ⇒ ::Google::Cloud::Container::V1::StatefulHAConfig
Optional.
Instance Attribute Details
#cloud_run_config ⇒ ::Google::Cloud::Container::V1::CloudRunConfig
Returns Configuration for the Cloud Run addon, which allows the user to use a managed Knative service.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#config_connector_config ⇒ ::Google::Cloud::Container::V1::ConfigConnectorConfig
Returns Configuration for the ConfigConnector add-on, a Kubernetes extension to manage hosted Google Cloud services through the Kubernetes API.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dns_cache_config ⇒ ::Google::Cloud::Container::V1::DnsCacheConfig
Returns Configuration for NodeLocalDNS, a dns cache running on cluster nodes.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gce_persistent_disk_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcePersistentDiskCsiDriverConfig
Returns Configuration for the Compute Engine Persistent Disk CSI driver.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcp_filestore_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcpFilestoreCsiDriverConfig
Returns Configuration for the Filestore CSI driver.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_fuse_csi_driver_config ⇒ ::Google::Cloud::Container::V1::GcsFuseCsiDriverConfig
Returns Configuration for the Cloud Storage Fuse CSI driver.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gke_backup_agent_config ⇒ ::Google::Cloud::Container::V1::GkeBackupAgentConfig
Returns Configuration for the Backup for GKE agent addon.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#high_scale_checkpointing_config ⇒ ::Google::Cloud::Container::V1::HighScaleCheckpointingConfig
Returns Configuration for the High Scale Checkpointing add-on.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#horizontal_pod_autoscaling ⇒ ::Google::Cloud::Container::V1::HorizontalPodAutoscaling
Returns Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#http_load_balancing ⇒ ::Google::Cloud::Container::V1::HttpLoadBalancing
Returns Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kubernetes_dashboard ⇒ ::Google::Cloud::Container::V1::KubernetesDashboard
This field is deprecated and may be removed in the next major version update.
Returns Configuration for the Kubernetes Dashboard. This addon is deprecated, and will be disabled in 1.15. It is recommended to use the Cloud Console to manage and monitor your Kubernetes clusters, workloads and applications. For more information, see: https://cloud.google.com/kubernetes-engine/docs/concepts/dashboards.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lustre_csi_driver_config ⇒ ::Google::Cloud::Container::V1::LustreCsiDriverConfig
Returns Configuration for the Lustre CSI driver.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network_policy_config ⇒ ::Google::Cloud::Container::V1::NetworkPolicyConfig
Returns Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parallelstore_csi_driver_config ⇒ ::Google::Cloud::Container::V1::ParallelstoreCsiDriverConfig
Returns Configuration for the Cloud Storage Parallelstore CSI driver.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ray_operator_config ⇒ ::Google::Cloud::Container::V1::RayOperatorConfig
Returns Optional. Configuration for Ray Operator addon.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slice_controller_config ⇒ ::Google::Cloud::Container::V1::SliceControllerConfig
Returns Optional. Configuration for the slice controller add-on.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#stateful_ha_config ⇒ ::Google::Cloud::Container::V1::StatefulHAConfig
Returns Optional. Configuration for the StatefulHA add-on.
1775 1776 1777 1778 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1775 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |