Class: Google::Cloud::Container::V1::AnonymousAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AnonymousAuthenticationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1::AnonymousAuthenticationConfig::Mode
Defines the mode of limiting anonymous access in the cluster.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1::AnonymousAuthenticationConfig::Mode
Returns Defines the mode of limiting anonymous access in the cluster.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3098 class AnonymousAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines the mode of anonymous authentication # allowed in the cluster. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Anonymous authentication is allowed for all endpoints. ENABLED = 1 # Anonymous authentication is allowed for only health check endpoints. LIMITED = 2 end end |