Class: Google::Cloud::Container::V1::BlueGreenSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Settings for blue-green upgrade.

Defined Under Namespace

Classes: AutoscaledRolloutPolicy, StandardRolloutPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaled_rollout_policy::Google::Cloud::Container::V1::BlueGreenSettings::AutoscaledRolloutPolicy

Returns Autoscaled policy for cluster autoscaler enabled blue-green upgrade.

Note: The following fields are mutually exclusive: autoscaled_rollout_policy, standard_rollout_policy. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4973

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#node_pool_soak_duration::Google::Protobuf::Duration

Returns Time needed after draining entire blue pool. After this period, blue pool will be cleaned up.

Returns:



4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4973

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#standard_rollout_policy::Google::Cloud::Container::V1::BlueGreenSettings::StandardRolloutPolicy

Returns Standard policy for the blue-green upgrade.

Note: The following fields are mutually exclusive: standard_rollout_policy, autoscaled_rollout_policy. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4973

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end