Class: Google::Cloud::Container::V1::ConfidentialNodes
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ConfidentialNodes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
Defined Under Namespace
Modules: ConfidentialInstanceType
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1::ConfidentialNodes::ConfidentialInstanceType
Defines the type of technology used by the confidential node.
-
#enabled ⇒ ::Boolean
Whether Confidential Nodes feature is enabled.
Instance Attribute Details
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1::ConfidentialNodes::ConfidentialInstanceType
Returns Defines the type of technology used by the confidential node.
7167 7168 7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7167 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |
#enabled ⇒ ::Boolean
Returns Whether Confidential Nodes feature is enabled.
7167 7168 7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7167 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |