Class: Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfigPair
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfigPair
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
CertificateConfigPair configures pairs of certificates, which is used for client certificate and key pairs under a registry.
Instance Attribute Summary collapse
-
#cert ⇒ ::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig
Cert configures the client certificate.
-
#key ⇒ ::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig
Key configures the client private key.
Instance Attribute Details
#cert ⇒ ::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig
Returns Cert configures the client certificate.
1481 1482 1483 1484 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1481 class CertificateConfigPair include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key ⇒ ::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig
Returns Key configures the client private key. Optional.
1481 1482 1483 1484 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1481 class CertificateConfigPair include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |