Class: Google::Cloud::Container::V1::ControlPlaneEndpointsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Configuration for all of the cluster's control plane endpoints.

Defined Under Namespace

Classes: DNSEndpointConfig, IPEndpointsConfig

Instance Attribute Summary collapse

Instance Attribute Details

#dns_endpoint_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig

Returns DNS endpoint configuration.



7817
7818
7819
7820
7821
7822
7823
7824
7825
7826
7827
7828
7829
7830
7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7817

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ip_endpoints_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::IPEndpointsConfig

Returns IP endpoints configuration.



7817
7818
7819
7820
7821
7822
7823
7824
7825
7826
7827
7828
7829
7830
7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7817

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end