Class: Google::Cloud::Container::V1::CustomImageConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::CustomImageConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
CustomImageConfig contains the information r
Instance Attribute Summary collapse
-
#image ⇒ ::String
The name of the image to use for this node.
-
#image_project ⇒ ::String
The project containing the image to use for this node.
Instance Attribute Details
#image ⇒ ::String
Returns The name of the image to use for this node.
1400 1401 1402 1403 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1400 class CustomImageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image_project ⇒ ::String
Returns The project containing the image to use for this node.
1400 1401 1402 1403 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1400 class CustomImageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |