Module: Google::Cloud::Container::V1::DatabaseEncryption::CurrentState
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Current State of etcd encryption.
Constant Summary collapse
- CURRENT_STATE_UNSPECIFIED =
Should never be set
0- CURRENT_STATE_ENCRYPTED =
Secrets in etcd are encrypted.
7- CURRENT_STATE_DECRYPTED =
Secrets in etcd are stored in plain text (at etcd level) - this is unrelated to Compute Engine level full disk encryption.
2- CURRENT_STATE_ENCRYPTION_PENDING =
Encryption (or re-encryption with a different CloudKMS key) of Secrets is in progress.
3- CURRENT_STATE_ENCRYPTION_ERROR =
Encryption (or re-encryption with a different CloudKMS key) of Secrets in etcd encountered an error.
4- CURRENT_STATE_DECRYPTION_PENDING =
De-crypting Secrets to plain text in etcd is in progress.
5- CURRENT_STATE_DECRYPTION_ERROR =
De-crypting Secrets to plain text in etcd encountered an error.
6- CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED =
Encryption of all objects in the storage is enabled. It does not guarantee that all objects in the storage are encrypted, but eventually they will be.
8- CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING =
Enablement of the encryption of all objects in storage is pending.
9- CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR =
Enabling encryption of all objects in storage encountered an error.
10