Class: Google::Cloud::Container::V1::DesiredEnterpriseConfig Deprecated

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Deprecated.

This message is deprecated and may be removed in the next major version update.

DesiredEnterpriseConfig is a wrapper used for updating enterprise_config.

Deprecated: GKE Enterprise features are now available without an Enterprise tier.

Instance Attribute Summary collapse

Instance Attribute Details

#desired_tier::Google::Cloud::Container::V1::EnterpriseConfig::ClusterTier

Returns desired_tier specifies the desired tier of the cluster.

Returns:



3456
3457
3458
3459
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3456

class DesiredEnterpriseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end