Class: Google::Cloud::Container::V1::EnterpriseConfig Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::EnterpriseConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Deprecated.
This message is deprecated and may be removed in the next major version update.
EnterpriseConfig is the cluster enterprise configuration.
Deprecated: GKE Enterprise features are now available without an Enterprise tier.
Defined Under Namespace
Modules: ClusterTier
Instance Attribute Summary collapse
-
#cluster_tier ⇒ ::Google::Cloud::Container::V1::EnterpriseConfig::ClusterTier
readonly
Output only.
-
#desired_tier ⇒ ::Google::Cloud::Container::V1::EnterpriseConfig::ClusterTier
Desired_tier specifies the desired tier of the cluster.
Instance Attribute Details
#cluster_tier ⇒ ::Google::Cloud::Container::V1::EnterpriseConfig::ClusterTier (readonly)
Returns Output only. cluster_tier indicates the effective tier of the cluster.
7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7489 class EnterpriseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Premium tiers for GKE Cluster. # # Deprecated: GKE Enterprise features are now available without an Enterprise # tier. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClusterTier # CLUSTER_TIER_UNSPECIFIED is when cluster_tier is not set. CLUSTER_TIER_UNSPECIFIED = 0 # STANDARD indicates a standard GKE cluster. STANDARD = 1 # ENTERPRISE indicates a GKE Enterprise cluster. ENTERPRISE = 2 end end |
#desired_tier ⇒ ::Google::Cloud::Container::V1::EnterpriseConfig::ClusterTier
Returns desired_tier specifies the desired tier of the cluster.
7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7489 class EnterpriseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Premium tiers for GKE Cluster. # # Deprecated: GKE Enterprise features are now available without an Enterprise # tier. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClusterTier # CLUSTER_TIER_UNSPECIFIED is when cluster_tier is not set. CLUSTER_TIER_UNSPECIFIED = 0 # STANDARD indicates a standard GKE cluster. STANDARD = 1 # ENTERPRISE indicates a GKE Enterprise cluster. ENTERPRISE = 2 end end |