Class: Google::Cloud::Container::V1::GPUDirectConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::GPUDirectConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
GPUDirectConfig specifies the GPU direct strategy on the node pool.
Defined Under Namespace
Modules: GPUDirectStrategy
Instance Attribute Summary collapse
-
#gpu_direct_strategy ⇒ ::Google::Cloud::Container::V1::GPUDirectConfig::GPUDirectStrategy
The type of GPU direct strategy to enable on the node pool.
Instance Attribute Details
#gpu_direct_strategy ⇒ ::Google::Cloud::Container::V1::GPUDirectConfig::GPUDirectStrategy
Returns The type of GPU direct strategy to enable on the node pool.
7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7087 class GPUDirectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Option for GPU direct Strategies module GPUDirectStrategy # Default value. No GPU Direct strategy is enabled on the node. GPU_DIRECT_STRATEGY_UNSPECIFIED = 0 # GPUDirect-RDMA on A3 Ultra, and A4 machine types RDMA = 2 end end |