Class: Google::Cloud::Container::V1::GPUSharingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::GPUSharingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
GPUSharingConfig represents the GPU sharing configuration for Hardware Accelerators.
Defined Under Namespace
Modules: GPUSharingStrategy
Instance Attribute Summary collapse
-
#gpu_sharing_strategy ⇒ ::Google::Cloud::Container::V1::GPUSharingConfig::GPUSharingStrategy
The type of GPU sharing strategy to enable on the GPU node.
-
#max_shared_clients_per_gpu ⇒ ::Integer
The max number of containers that can share a physical GPU.
Instance Attribute Details
#gpu_sharing_strategy ⇒ ::Google::Cloud::Container::V1::GPUSharingConfig::GPUSharingStrategy
Returns The type of GPU sharing strategy to enable on the GPU node.
6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 6121 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6106 class GPUSharingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of GPU sharing strategy currently provided. module GPUSharingStrategy # Default value. GPU_SHARING_STRATEGY_UNSPECIFIED = 0 # GPUs are time-shared between containers. TIME_SHARING = 1 # GPUs are shared between containers with NVIDIA MPS. MPS = 2 end end |
#max_shared_clients_per_gpu ⇒ ::Integer
Returns The max number of containers that can share a physical GPU.
6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 6121 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6106 class GPUSharingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of GPU sharing strategy currently provided. module GPUSharingStrategy # Default value. GPU_SHARING_STRATEGY_UNSPECIFIED = 0 # GPUs are time-shared between containers. TIME_SHARING = 1 # GPUs are shared between containers with NVIDIA MPS. MPS = 2 end end |