Class: Google::Cloud::Container::V1::HighScaleCheckpointingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::HighScaleCheckpointingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration for the High Scale Checkpointing.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Whether the High Scale Checkpointing is enabled for this cluster.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Whether the High Scale Checkpointing is enabled for this cluster.
1999 2000 2001 2002 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1999 class HighScaleCheckpointingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |