Class: Google::Cloud::Container::V1::LinuxNodeConfig::CustomNodeInit::InitScript
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::LinuxNodeConfig::CustomNodeInit::InitScript
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
InitScript provide a simply bash script to be executed on the node.
Instance Attribute Summary collapse
-
#args ⇒ ::Array<::String>
Optional.
-
#gcp_secret_manager_secret_uri ⇒ ::String
The resource name of the secret manager secret hosting the init script.
-
#gcs_generation ⇒ ::Integer
The generation of the init script stored in Gloud Storage.
-
#gcs_uri ⇒ ::String
The Cloud Storage URI for storing the init script.
Instance Attribute Details
#args ⇒ ::Array<::String>
Returns Optional. The optional arguments line to be passed to the init script.
178 179 180 181 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 178 class InitScript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcp_secret_manager_secret_uri ⇒ ::String
Returns The resource name of the secret manager secret hosting the init script. Both global and regional secrets are supported with format below: Global secret: projects/{project}/secrets/{secret}/versions/{version} Regional secret: projects/{project}/locations/{location}/secrets/{secret}/versions/{version} Example: projects/1234567890/secrets/script_1/versions/1. Accept version number only, not support version alias. User can't configure both gcp_secret_manager_secret_uri and gcs_uri.
178 179 180 181 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 178 class InitScript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_generation ⇒ ::Integer
Returns The generation of the init script stored in Gloud Storage.
This is the required field to identify the version of the
init script.
User can get the genetaion from
gcloud storage objects describe gs://BUCKET_NAME/OBJECT_NAME
--format="value(generation)" or from the "Version history" tab of the
object in the Cloud Console UI.
178 179 180 181 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 178 class InitScript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_uri ⇒ ::String
Returns The Cloud Storage URI for storing the init script. Format: gs://BUCKET_NAME/OBJECT_NAME The service account on the node pool must have read access to the object. User can't configure both gcs_uri and gcp_secret_manager_secret_uri.
178 179 180 181 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 178 class InitScript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |