Class: Google::Cloud::Container::V1::MaintenanceWindow

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

MaintenanceWindow defines the maintenance window to be used for the cluster.

Defined Under Namespace

Classes: MaintenanceExclusionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#daily_maintenance_window::Google::Cloud::Container::V1::DailyMaintenanceWindow

Returns DailyMaintenanceWindow specifies a daily maintenance operation window.

Note: The following fields are mutually exclusive: daily_maintenance_window, recurring_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Container::V1::DailyMaintenanceWindow)

    DailyMaintenanceWindow specifies a daily maintenance operation window.

    Note: The following fields are mutually exclusive: daily_maintenance_window, recurring_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.



5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5481

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Container::V1::TimeWindow]
  class MaintenanceExclusionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_exclusions::Google::Protobuf::Map{::String => ::Google::Cloud::Container::V1::TimeWindow}

Returns Exceptions to maintenance window. Non-emergency maintenance should not occur in these windows.

Returns:



5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5481

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Container::V1::TimeWindow]
  class MaintenanceExclusionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#recurring_maintenance_window::Google::Cloud::Container::V1::RecurringMaintenanceWindow

Returns RecurringMaintenanceWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time. Alternative to RecurringWindow, with renamed fields.

Note: The following fields are mutually exclusive: recurring_maintenance_window, daily_maintenance_window, recurring_window. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Container::V1::RecurringMaintenanceWindow)

    RecurringMaintenanceWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time. Alternative to RecurringWindow, with renamed fields.

    Note: The following fields are mutually exclusive: recurring_maintenance_window, daily_maintenance_window, recurring_window. If a field in that set is populated, all other fields in the set will automatically be cleared.



5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5481

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Container::V1::TimeWindow]
  class MaintenanceExclusionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#recurring_window::Google::Cloud::Container::V1::RecurringTimeWindow

Returns RecurringWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time.

Note: The following fields are mutually exclusive: recurring_window, daily_maintenance_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Container::V1::RecurringTimeWindow)

    RecurringWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time.

    Note: The following fields are mutually exclusive: recurring_window, daily_maintenance_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.



5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5481

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Container::V1::TimeWindow]
  class MaintenanceExclusionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end