Class: Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.
Defined Under Namespace
Classes: CidrBlock
Instance Attribute Summary collapse
-
#cidr_blocks ⇒ ::Array<::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig::CidrBlock>
Cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
-
#enabled ⇒ ::Boolean
Whether or not master authorized networks is enabled.
-
#gcp_public_cidrs_access_enabled ⇒ ::Boolean
Whether master is accessible via Google Compute Engine Public IP addresses.
-
#private_endpoint_enforcement_enabled ⇒ ::Boolean
Whether master authorized networks is enforced on private endpoint or not.
Instance Attribute Details
#cidr_blocks ⇒ ::Array<::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig::CidrBlock>
Returns cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2285 class MasterAuthorizedNetworksConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CidrBlock contains an optional name and one CIDR block. # @!attribute [rw] display_name # @return [::String] # display_name is an optional field for users to identify CIDR blocks. # @!attribute [rw] cidr_block # @return [::String] # cidr_block must be specified in CIDR notation. class CidrBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enabled ⇒ ::Boolean
Returns Whether or not master authorized networks is enabled.
2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2285 class MasterAuthorizedNetworksConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CidrBlock contains an optional name and one CIDR block. # @!attribute [rw] display_name # @return [::String] # display_name is an optional field for users to identify CIDR blocks. # @!attribute [rw] cidr_block # @return [::String] # cidr_block must be specified in CIDR notation. class CidrBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gcp_public_cidrs_access_enabled ⇒ ::Boolean
Returns Whether master is accessible via Google Compute Engine Public IP addresses.
2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2285 class MasterAuthorizedNetworksConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CidrBlock contains an optional name and one CIDR block. # @!attribute [rw] display_name # @return [::String] # display_name is an optional field for users to identify CIDR blocks. # @!attribute [rw] cidr_block # @return [::String] # cidr_block must be specified in CIDR notation. class CidrBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#private_endpoint_enforcement_enabled ⇒ ::Boolean
Returns Whether master authorized networks is enforced on private endpoint or not.
2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2285 class MasterAuthorizedNetworksConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CidrBlock contains an optional name and one CIDR block. # @!attribute [rw] display_name # @return [::String] # display_name is an optional field for users to identify CIDR blocks. # @!attribute [rw] cidr_block # @return [::String] # cidr_block must be specified in CIDR notation. class CidrBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |