Class: Google::Cloud::Container::V1::NetworkConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

NetworkConfig reports the relative names of network & subnetwork.

Defined Under Namespace

Classes: ClusterNetworkPerformanceConfig

Instance Attribute Summary collapse

Instance Attribute Details

#datapath_provider::Google::Cloud::Container::V1::DatapathProvider

Returns The desired datapath provider for this cluster. By default, uses the IPTables-based kube-proxy implementation.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#dataplane_v2_config::Google::Cloud::Container::V1::DataplaneV2Config

Returns Optional. DataplaneV2Config specifies the DPv2 configuration.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#default_enable_private_nodes::Boolean

Returns Controls whether by default nodes have private IP addresses only. It is invalid to specify both [PrivateClusterConfig.enablePrivateNodes][] and this field at the same time. To update the default setting, use ClusterUpdate.desired_default_enable_private_nodes.

Returns:

  • (::Boolean)

    Controls whether by default nodes have private IP addresses only. It is invalid to specify both [PrivateClusterConfig.enablePrivateNodes][] and this field at the same time. To update the default setting, use ClusterUpdate.desired_default_enable_private_nodes



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#default_snat_status::Google::Cloud::Container::V1::DefaultSnatStatus

Returns Whether the cluster disables default in-node sNAT rules. In-node sNAT rules will be disabled when default_snat_status is disabled. When disabled is set to false, default IP masquerade rules will be applied to the nodes to prevent sNAT on cluster internal traffic.

Returns:

  • (::Google::Cloud::Container::V1::DefaultSnatStatus)

    Whether the cluster disables default in-node sNAT rules. In-node sNAT rules will be disabled when default_snat_status is disabled. When disabled is set to false, default IP masquerade rules will be applied to the nodes to prevent sNAT on cluster internal traffic.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#disable_l4_lb_firewall_reconciliation::Boolean

Returns Disable L4 load balancer VPC firewalls to enable firewall policies.

Returns:

  • (::Boolean)

    Disable L4 load balancer VPC firewalls to enable firewall policies.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#dns_config::Google::Cloud::Container::V1::DNSConfig

Returns DNSConfig contains clusterDNS config for this cluster.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#enable_cilium_clusterwide_network_policy::Boolean

Returns Whether CiliumClusterwideNetworkPolicy is enabled on this cluster.

Returns:

  • (::Boolean)

    Whether CiliumClusterwideNetworkPolicy is enabled on this cluster.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#enable_fqdn_network_policy::Boolean

Returns Whether FQDN Network Policy is enabled on this cluster.

Returns:

  • (::Boolean)

    Whether FQDN Network Policy is enabled on this cluster.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#enable_intra_node_visibility::Boolean

Returns Whether Intra-node visibility is enabled for this cluster. This makes same node pod to pod traffic visible for VPC network.

Returns:

  • (::Boolean)

    Whether Intra-node visibility is enabled for this cluster. This makes same node pod to pod traffic visible for VPC network.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#enable_l4ilb_subsetting::Boolean

Returns Whether L4ILB Subsetting is enabled for this cluster.

Returns:

  • (::Boolean)

    Whether L4ILB Subsetting is enabled for this cluster.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#enable_multi_networking::Boolean

Returns Whether multi-networking is enabled for this cluster.

Returns:

  • (::Boolean)

    Whether multi-networking is enabled for this cluster.



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#gateway_api_config::Google::Cloud::Container::V1::GatewayAPIConfig

Returns GatewayAPIConfig contains the desired config of Gateway API on this cluster.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#in_transit_encryption_config::Google::Cloud::Container::V1::InTransitEncryptionConfig

Returns Specify the details of in-transit encryption. Now named inter-node transparent encryption.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#network::String (readonly)

Returns Output only. The relative name of the Google Compute Engine network to which the cluster is connected. Example: projects/my-project/global/networks/my-network.

Returns:

  • (::String)

    Output only. The relative name of the Google Compute Engine network to which the cluster is connected. Example: projects/my-project/global/networks/my-network



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#network_performance_config::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig

Returns Network bandwidth tier configuration.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#private_ipv6_google_access::Google::Cloud::Container::V1::PrivateIPv6GoogleAccess

Returns The desired state of IPv6 connectivity to Google Services. By default, no private IPv6 access to or from Google Services (all access will be via IPv4).

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#service_external_ips_config::Google::Cloud::Container::V1::ServiceExternalIPsConfig

Returns ServiceExternalIPsConfig specifies if services with externalIPs field are blocked or not.

Returns:



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end

#subnetwork::String (readonly)

Returns Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected. Example: projects/my-project/regions/us-central1/subnetworks/my-subnet.

Returns:

  • (::String)

    Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected. Example: projects/my-project/regions/us-central1/subnetworks/my-subnet



6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6412

class NetworkConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of network bandwidth tiers
  # @!attribute [rw] total_egress_bandwidth_tier
  #   @return [::Google::Cloud::Container::V1::NetworkConfig::ClusterNetworkPerformanceConfig::Tier]
  #     Specifies the total network bandwidth tier for NodePools in the cluster.
  class ClusterNetworkPerformanceConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Node network tier
    module Tier
      # Default value
      TIER_UNSPECIFIED = 0

      # Higher bandwidth, actual values based on VM size.
      TIER_1 = 1
    end
  end
end