Class: Google::Cloud::Container::V1::NotificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

NotificationConfig is the configuration of notifications.

Defined Under Namespace

Modules: EventType Classes: Filter, PubSub

Instance Attribute Summary collapse

Instance Attribute Details

#pubsub::Google::Cloud::Container::V1::NotificationConfig::PubSub

Returns Notification config for Pub/Sub.

Returns:



7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7105

class NotificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pub/Sub specific notification config.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enable notifications for Pub/Sub.
  # @!attribute [rw] topic
  #   @return [::String]
  #     The desired Pub/Sub topic to which notifications will be
  #     sent by GKE. Format is `projects/{project}/topics/{topic}`.
  # @!attribute [rw] filter
  #   @return [::Google::Cloud::Container::V1::NotificationConfig::Filter]
  #     Allows filtering to one or more specific event types. If no filter is
  #     specified, or if a filter is specified with no event types, all event
  #     types will be sent
  class PubSub
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Allows filtering to one or more specific event types. If event types are
  # present, those and only those event types will be transmitted to the
  # cluster. Other types will be skipped. If no filter is specified, or no
  # event types are present, all event types will be sent
  # @!attribute [rw] event_type
  #   @return [::Array<::Google::Cloud::Container::V1::NotificationConfig::EventType>]
  #     Event types to allowlist.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of notifications currently supported. Can be used to filter what
  # notifications are sent.
  module EventType
    # Not set, will be ignored.
    EVENT_TYPE_UNSPECIFIED = 0

    # Corresponds with UpgradeAvailableEvent.
    UPGRADE_AVAILABLE_EVENT = 1

    # Corresponds with UpgradeEvent.
    UPGRADE_EVENT = 2

    # Corresponds with SecurityBulletinEvent.
    SECURITY_BULLETIN_EVENT = 3

    # Corresponds with UpgradeInfoEvent.
    UPGRADE_INFO_EVENT = 4
  end
end