Class: Google::Cloud::Container::V1::OperationProgress
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::OperationProgress
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Information about operation (or operation stage) progress.
Defined Under Namespace
Classes: Metric
Instance Attribute Summary collapse
-
#metrics ⇒ ::Array<::Google::Cloud::Container::V1::OperationProgress::Metric>
Progress metric bundle, for example: metrics: [{name: "nodes done", int_value: 15}, {name: "nodes total", int_value: 32}] or metrics: [{name: "progress", double_value: 0.56}, {name: "progress scale", double_value: 1.0}].
-
#name ⇒ ::String
A non-parameterized string describing an operation stage.
-
#stages ⇒ ::Array<::Google::Cloud::Container::V1::OperationProgress>
Substages of an operation or a stage.
-
#status ⇒ ::Google::Cloud::Container::V1::Operation::Status
Status of an operation stage.
Instance Attribute Details
#metrics ⇒ ::Array<::Google::Cloud::Container::V1::OperationProgress::Metric>
Returns Progress metric bundle, for example: metrics: [{name: "nodes done", int_value: 15}, {name: "nodes total", int_value: 32}] or metrics: [{name: "progress", double_value: 0.56}, {name: "progress scale", double_value: 1.0}].
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4014 class OperationProgress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Progress metric is (string, int|float|string) pair. # @!attribute [rw] name # @return [::String] # Required. Metric name, e.g., "nodes total", "percent done". # @!attribute [rw] int_value # @return [::Integer] # For metrics with integer value. # # Note: The following fields are mutually exclusive: `int_value`, `double_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_value # @return [::Float] # For metrics with floating point value. # # Note: The following fields are mutually exclusive: `double_value`, `int_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_value # @return [::String] # For metrics with custom values (ratios, visual progress, etc.). # # Note: The following fields are mutually exclusive: `string_value`, `int_value`, `double_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns A non-parameterized string describing an operation stage. Unset for single-stage operations.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4014 class OperationProgress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Progress metric is (string, int|float|string) pair. # @!attribute [rw] name # @return [::String] # Required. Metric name, e.g., "nodes total", "percent done". # @!attribute [rw] int_value # @return [::Integer] # For metrics with integer value. # # Note: The following fields are mutually exclusive: `int_value`, `double_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_value # @return [::Float] # For metrics with floating point value. # # Note: The following fields are mutually exclusive: `double_value`, `int_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_value # @return [::String] # For metrics with custom values (ratios, visual progress, etc.). # # Note: The following fields are mutually exclusive: `string_value`, `int_value`, `double_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#stages ⇒ ::Array<::Google::Cloud::Container::V1::OperationProgress>
Returns Substages of an operation or a stage.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4014 class OperationProgress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Progress metric is (string, int|float|string) pair. # @!attribute [rw] name # @return [::String] # Required. Metric name, e.g., "nodes total", "percent done". # @!attribute [rw] int_value # @return [::Integer] # For metrics with integer value. # # Note: The following fields are mutually exclusive: `int_value`, `double_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_value # @return [::Float] # For metrics with floating point value. # # Note: The following fields are mutually exclusive: `double_value`, `int_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_value # @return [::String] # For metrics with custom values (ratios, visual progress, etc.). # # Note: The following fields are mutually exclusive: `string_value`, `int_value`, `double_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#status ⇒ ::Google::Cloud::Container::V1::Operation::Status
Returns Status of an operation stage. Unset for single-stage operations.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4014 class OperationProgress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Progress metric is (string, int|float|string) pair. # @!attribute [rw] name # @return [::String] # Required. Metric name, e.g., "nodes total", "percent done". # @!attribute [rw] int_value # @return [::Integer] # For metrics with integer value. # # Note: The following fields are mutually exclusive: `int_value`, `double_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_value # @return [::Float] # For metrics with floating point value. # # Note: The following fields are mutually exclusive: `double_value`, `int_value`, `string_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_value # @return [::String] # For metrics with custom values (ratios, visual progress, etc.). # # Note: The following fields are mutually exclusive: `string_value`, `int_value`, `double_value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Metric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |