Class: Google::Cloud::Container::V1::RecurringMaintenanceWindow

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Represents an arbitrary window of time that recurs. Will replace RecurringTimeWindow.

Instance Attribute Summary collapse

Instance Attribute Details

#delay_until::Google::Type::Date

Returns Optional. Specifies the date before which will not be scheduled. Depending on the recurrence, this may be the date the first window appears. Days are measured in the UTC timezone. This setting must be used when INTERVAL>1 or FREQ=WEEKLY/MONTHLY and no BYDAY specified.

Returns:

  • (::Google::Type::Date)

    Optional. Specifies the date before which will not be scheduled. Depending on the recurrence, this may be the date the first window appears. Days are measured in the UTC timezone. This setting must be used when INTERVAL>1 or FREQ=WEEKLY/MONTHLY and no BYDAY specified.



5626
5627
5628
5629
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5626

class RecurringMaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#recurrence::String

Returns Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window recurs.

For example, to have something repeat every weekday, you'd use: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR

To repeat some window daily (equivalent to the DailyMaintenanceWindow): FREQ=DAILY

For the first weekend of every month: FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU

The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported.

Returns:

  • (::String)

    Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window recurs.

    For example, to have something repeat every weekday, you'd use: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR

    To repeat some window daily (equivalent to the DailyMaintenanceWindow): FREQ=DAILY

    For the first weekend of every month: FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU

    The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported.



5626
5627
5628
5629
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5626

class RecurringMaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#window_duration::Google::Protobuf::Duration

Returns Required. Duration of the window.

Returns:



5626
5627
5628
5629
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5626

class RecurringMaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#window_start_time::Google::Type::TimeOfDay

Returns Required. Start time of the window on days that it is scheduled, assuming UTC timezone.

Returns:



5626
5627
5628
5629
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5626

class RecurringMaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end