Class: Google::Cloud::Container::V1::ReservationAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ReservationAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ReservationAffinity is the configuration of desired reservation which instances could take capacity from.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#consume_reservation_type ⇒ ::Google::Cloud::Container::V1::ReservationAffinity::Type
Corresponds to the type of reservation consumption.
-
#key ⇒ ::String
Corresponds to the label key of a reservation resource.
-
#values ⇒ ::Array<::String>
Corresponds to the label value(s) of reservation resource(s).
Instance Attribute Details
#consume_reservation_type ⇒ ::Google::Cloud::Container::V1::ReservationAffinity::Type
Returns Corresponds to the type of reservation consumption.
1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1448 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |
#key ⇒ ::String
Returns Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify "compute.googleapis.com/reservation-name" as the key and specify the name of your reservation as its value.
1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1448 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |
#values ⇒ ::Array<::String>
Returns Corresponds to the label value(s) of reservation resource(s).
1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1448 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether to consume capacity from a reservation or not. module Type # Default value. This should not be used. UNSPECIFIED = 0 # Do not consume from any reserved capacity. NO_RESERVATION = 1 # Consume any reservation available. ANY_RESERVATION = 2 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 3 end end |