Class: Google::Cloud::Container::V1::ResourceUsageExportConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Configuration for exporting cluster resource usages.

Defined Under Namespace

Classes: BigQueryDestination, ConsumptionMeteringConfig

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_destination::Google::Cloud::Container::V1::ResourceUsageExportConfig::BigQueryDestination

Returns Configuration to use BigQuery as usage export destination.

Returns:



7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7010

class ResourceUsageExportConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for using BigQuery as the destination of resource usage export.
  # @!attribute [rw] dataset_id
  #   @return [::String]
  #     The ID of a BigQuery Dataset.
  class BigQueryDestination
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Parameters for controlling consumption metering.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Whether to enable consumption metering for this cluster. If enabled, a
  #     second BigQuery table will be created to hold resource consumption
  #     records.
  class ConsumptionMeteringConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#consumption_metering_config::Google::Cloud::Container::V1::ResourceUsageExportConfig::ConsumptionMeteringConfig

Returns Configuration to enable resource consumption metering.

Returns:



7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7010

class ResourceUsageExportConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for using BigQuery as the destination of resource usage export.
  # @!attribute [rw] dataset_id
  #   @return [::String]
  #     The ID of a BigQuery Dataset.
  class BigQueryDestination
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Parameters for controlling consumption metering.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Whether to enable consumption metering for this cluster. If enabled, a
  #     second BigQuery table will be created to hold resource consumption
  #     records.
  class ConsumptionMeteringConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#enable_network_egress_metering::Boolean

Returns Whether to enable network egress metering for this cluster. If enabled, a daemonset will be created in the cluster to meter network egress traffic.

Returns:

  • (::Boolean)

    Whether to enable network egress metering for this cluster. If enabled, a daemonset will be created in the cluster to meter network egress traffic.



7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7010

class ResourceUsageExportConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for using BigQuery as the destination of resource usage export.
  # @!attribute [rw] dataset_id
  #   @return [::String]
  #     The ID of a BigQuery Dataset.
  class BigQueryDestination
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Parameters for controlling consumption metering.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Whether to enable consumption metering for this cluster. If enabled, a
  #     second BigQuery table will be created to hold resource consumption
  #     records.
  class ConsumptionMeteringConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end