Class: Google::Cloud::Container::V1::SecurityPostureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.

Defined Under Namespace

Modules: Mode, VulnerabilityMode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::Container::V1::SecurityPostureConfig::Mode

Returns Sets which mode to use for Security Posture features.

Returns:



3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3205

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Deprecated: Security Posture Enterprise features are no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Deprecated: Basic vulnerability scanning is no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end

#vulnerability_mode::Google::Cloud::Container::V1::SecurityPostureConfig::VulnerabilityMode

Returns Sets which mode to use for vulnerability scanning.

Returns:



3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3205

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Deprecated: Security Posture Enterprise features are no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Deprecated: Basic vulnerability scanning is no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end