Class: Google::Cloud::Container::V1::SetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::SetLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster
Defined Under Namespace
Classes: ResourceLabelsEntry
Instance Attribute Summary collapse
-
#cluster_id ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#label_fingerprint ⇒ ::String
Required.
-
#name ⇒ ::String
The name (project, location, cluster name) of the cluster to set labels.
-
#project_id ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#resource_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Required.
-
#zone ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#cluster_id ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#label_fingerprint ⇒ ::String
Returns Required. The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by
Kubernetes Engine and changes after every request to modify or update
labels. You must always provide an up-to-date fingerprint hash when
updating or changing labels. Make a get() request to the
resource to get the latest fingerprint.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns The name (project, location, cluster name) of the cluster to set labels.
Specified in the format projects/*/locations/*/clusters/*.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#project_id ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resource_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Required. The labels to set for that cluster.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#zone ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.
5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5594 class SetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |