Class: Google::Cloud::Container::V1::SetNetworkPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_id::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field.

Returns:

  • (::String)

    Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field.



6202
6203
6204
6205
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6202

class SetNetworkPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*.

Returns:

  • (::String)

    The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*.



6202
6203
6204
6205
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6202

class SetNetworkPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#network_policy::Google::Cloud::Container::V1::NetworkPolicy

Returns Required. Configuration options for the NetworkPolicy feature.

Returns:



6202
6203
6204
6205
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6202

class SetNetworkPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.

Returns:

  • (::String)

    Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.



6202
6203
6204
6205
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6202

class SetNetworkPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.

Returns:

  • (::String)

    Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.



6202
6203
6204
6205
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6202

class SetNetworkPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end