Module: Google::Cloud::Container::V1::TaintConfig::ArchitectureTaintBehavior

Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Controls architecture tainting behavior for a node pool. New values may be added in the future.

Constant Summary collapse

ARCHITECTURE_TAINT_BEHAVIOR_UNSPECIFIED =

Specifies that the behavior is unspecified, defaults to ARM.

0
NONE =

Disables default architecture taints on the node pool.

1
ARM =

Taints all the nodes in the node pool with the default ARM taint.

2