Class: Google::Cloud::Container::V1::AdvancedMachineFeatures
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AdvancedMachineFeatures
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Specifies options for controlling advanced machine features.
Defined Under Namespace
Modules: PerformanceMonitoringUnit
Instance Attribute Summary collapse
-
#enable_nested_virtualization ⇒ ::Boolean
Whether or not to enable nested virtualization (defaults to false).
-
#performance_monitoring_unit ⇒ ::Google::Cloud::Container::V1::AdvancedMachineFeatures::PerformanceMonitoringUnit
Type of Performance Monitoring Unit (PMU) requested on node pool instances.
-
#threads_per_core ⇒ ::Integer
The number of threads per physical core.
Instance Attribute Details
#enable_nested_virtualization ⇒ ::Boolean
Returns Whether or not to enable nested virtualization (defaults to false).
1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1197 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Level of PMU access. module PerformanceMonitoringUnit # PMU not enabled. PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 1 # Most documented core/L2 events. STANDARD = 2 # Most documented core/L2 and LLC events. ENHANCED = 3 end end |
#performance_monitoring_unit ⇒ ::Google::Cloud::Container::V1::AdvancedMachineFeatures::PerformanceMonitoringUnit
Returns Type of Performance Monitoring Unit (PMU) requested on node pool instances. If unset, PMU will not be available to the node.
1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1197 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Level of PMU access. module PerformanceMonitoringUnit # PMU not enabled. PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 1 # Most documented core/L2 events. STANDARD = 2 # Most documented core/L2 and LLC events. ENHANCED = 3 end end |
#threads_per_core ⇒ ::Integer
Returns The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.
1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1197 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Level of PMU access. module PerformanceMonitoringUnit # PMU not enabled. PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 1 # Most documented core/L2 events. STANDARD = 2 # Most documented core/L2 and LLC events. ENHANCED = 3 end end |