Class: Google::Cloud::Container::V1::AdvancedMachineFeatures

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Specifies options for controlling advanced machine features.

Defined Under Namespace

Modules: PerformanceMonitoringUnit

Instance Attribute Summary collapse

Instance Attribute Details

#enable_nested_virtualization::Boolean

Returns Whether or not to enable nested virtualization (defaults to false).

Returns:

  • (::Boolean)

    Whether or not to enable nested virtualization (defaults to false).



1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1069

class AdvancedMachineFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Level of PMU access.
  module PerformanceMonitoringUnit
    # PMU not enabled.
    PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0

    # Architecturally defined non-LLC events.
    ARCHITECTURAL = 1

    # Most documented core/L2 events.
    STANDARD = 2

    # Most documented core/L2 and LLC events.
    ENHANCED = 3
  end
end

#performance_monitoring_unit::Google::Cloud::Container::V1::AdvancedMachineFeatures::PerformanceMonitoringUnit

Returns Type of Performance Monitoring Unit (PMU) requested on node pool instances. If unset, PMU will not be available to the node.

Returns:



1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1069

class AdvancedMachineFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Level of PMU access.
  module PerformanceMonitoringUnit
    # PMU not enabled.
    PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0

    # Architecturally defined non-LLC events.
    ARCHITECTURAL = 1

    # Most documented core/L2 events.
    STANDARD = 2

    # Most documented core/L2 and LLC events.
    ENHANCED = 3
  end
end

#threads_per_core::Integer

Returns The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.

Returns:

  • (::Integer)

    The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.



1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1069

class AdvancedMachineFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Level of PMU access.
  module PerformanceMonitoringUnit
    # PMU not enabled.
    PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 0

    # Architecturally defined non-LLC events.
    ARCHITECTURAL = 1

    # Most documented core/L2 events.
    STANDARD = 2

    # Most documented core/L2 and LLC events.
    ENHANCED = 3
  end
end