Class: Google::Cloud::Container::V1::AnonymousAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AnonymousAuthenticationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1::AnonymousAuthenticationConfig::Mode
Defines the mode of limiting anonymous access in the cluster.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1::AnonymousAuthenticationConfig::Mode
Returns Defines the mode of limiting anonymous access in the cluster.
2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2868 class AnonymousAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines the mode of anonymous authentication # allowed in the cluster. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Anonymous authentication is allowed for all endpoints. ENABLED = 1 # Anonymous authentication is allowed for only health check endpoints. LIMITED = 2 end end |