Class: Google::Cloud::Container::V1::Autopilot
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::Autopilot
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Autopilot is the configuration for Autopilot settings on the cluster.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Enable Autopilot.
-
#privileged_admission_config ⇒ ::Google::Cloud::Container::V1::PrivilegedAdmissionConfig
PrivilegedAdmissionConfig is the configuration related to privileged admission control.
-
#workload_policy_config ⇒ ::Google::Cloud::Container::V1::WorkloadPolicyConfig
WorkloadPolicyConfig is the configuration related to GCW workload policy.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Enable Autopilot.
6986 6987 6988 6989 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6986 class Autopilot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#privileged_admission_config ⇒ ::Google::Cloud::Container::V1::PrivilegedAdmissionConfig
Returns PrivilegedAdmissionConfig is the configuration related to privileged admission control.
6986 6987 6988 6989 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6986 class Autopilot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workload_policy_config ⇒ ::Google::Cloud::Container::V1::WorkloadPolicyConfig
Returns WorkloadPolicyConfig is the configuration related to GCW workload policy.
6986 6987 6988 6989 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6986 class Autopilot include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |