Class: Google::Cloud::Container::V1::AutopilotCompatibilityIssue
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AutopilotCompatibilityIssue
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
AutopilotCompatibilityIssue contains information about a specific compatibility issue with Autopilot mode.
Defined Under Namespace
Modules: IssueType
Instance Attribute Summary collapse
-
#constraint_type ⇒ ::String
The constraint type of the issue.
-
#description ⇒ ::String
The description of the issue.
-
#documentation_url ⇒ ::String
A URL to a public documentation, which addresses resolving this issue.
-
#incompatibility_type ⇒ ::Google::Cloud::Container::V1::AutopilotCompatibilityIssue::IssueType
The incompatibility type of this issue.
-
#last_observation ⇒ ::Google::Protobuf::Timestamp
The last time when this issue was observed.
-
#subjects ⇒ ::Array<::String>
The name of the resources which are subject to this issue.
Instance Attribute Details
#constraint_type ⇒ ::String
Returns The constraint type of the issue.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#description ⇒ ::String
Returns The description of the issue.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#documentation_url ⇒ ::String
Returns A URL to a public documentation, which addresses resolving this issue.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#incompatibility_type ⇒ ::Google::Cloud::Container::V1::AutopilotCompatibilityIssue::IssueType
Returns The incompatibility type of this issue.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#last_observation ⇒ ::Google::Protobuf::Timestamp
Returns The last time when this issue was observed.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#subjects ⇒ ::Array<::String>
Returns The name of the resources which are subject to this issue.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6542 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |