Class: Google::Cloud::Container::V1::AutopilotCompatibilityIssue
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::AutopilotCompatibilityIssue
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
AutopilotCompatibilityIssue contains information about a specific compatibility issue with Autopilot mode.
Defined Under Namespace
Modules: IssueType
Instance Attribute Summary collapse
-
#constraint_type ⇒ ::String
The constraint type of the issue.
-
#description ⇒ ::String
The description of the issue.
-
#documentation_url ⇒ ::String
A URL to a public documentation, which addresses resolving this issue.
-
#incompatibility_type ⇒ ::Google::Cloud::Container::V1::AutopilotCompatibilityIssue::IssueType
The incompatibility type of this issue.
-
#last_observation ⇒ ::Google::Protobuf::Timestamp
The last time when this issue was observed.
-
#subjects ⇒ ::Array<::String>
The name of the resources which are subject to this issue.
Instance Attribute Details
#constraint_type ⇒ ::String
Returns The constraint type of the issue.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#description ⇒ ::String
Returns The description of the issue.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#documentation_url ⇒ ::String
Returns A URL to a public documentation, which addresses resolving this issue.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#incompatibility_type ⇒ ::Google::Cloud::Container::V1::AutopilotCompatibilityIssue::IssueType
Returns The incompatibility type of this issue.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#last_observation ⇒ ::Google::Protobuf::Timestamp
Returns The last time when this issue was observed.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |
#subjects ⇒ ::Array<::String>
Returns The name of the resources which are subject to this issue.
6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 6179 6180 6181 6182 6183 6184 6185 6186 6187 6188 6189 6190 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6168 class AutopilotCompatibilityIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the reported issue. module IssueType # Default value, should not be used. UNSPECIFIED = 0 # Indicates that the issue is a known incompatibility between the # cluster and Autopilot mode. INCOMPATIBILITY = 1 # Indicates the issue is an incompatibility if customers take no further # action to resolve. ADDITIONAL_CONFIG_REQUIRED = 2 # Indicates the issue is not an incompatibility, but depending on the # workloads business logic, there is a potential that they won't work on # Autopilot. PASSED_WITH_OPTIONAL_CONFIG = 3 end end |