Class: Google::Cloud::Container::V1::BinaryAuthorization
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::BinaryAuthorization
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration for Binary Authorization.
Defined Under Namespace
Modules: EvaluationMode
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#evaluation_mode ⇒ ::Google::Cloud::Container::V1::BinaryAuthorization::EvaluationMode
Mode of operation for binauthz policy evaluation.
Instance Attribute Details
#enabled ⇒ ::Boolean
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns This field is deprecated. Leave this unset and instead configure BinaryAuthorization using evaluation_mode. If evaluation_mode is set to anything other than EVALUATION_MODE_UNSPECIFIED, this field is ignored.
2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2149 class BinaryAuthorization include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Binary Authorization mode of operation. module EvaluationMode # Default value EVALUATION_MODE_UNSPECIFIED = 0 # Disable BinaryAuthorization DISABLED = 1 # Enforce Kubernetes admission requests with BinaryAuthorization using the # project's singleton policy. This is equivalent to setting the # enabled boolean to true. PROJECT_SINGLETON_POLICY_ENFORCE = 2 end end |
#evaluation_mode ⇒ ::Google::Cloud::Container::V1::BinaryAuthorization::EvaluationMode
Returns Mode of operation for binauthz policy evaluation. If unspecified, defaults to DISABLED.
2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2149 class BinaryAuthorization include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Binary Authorization mode of operation. module EvaluationMode # Default value EVALUATION_MODE_UNSPECIFIED = 0 # Disable BinaryAuthorization DISABLED = 1 # Enforce Kubernetes admission requests with BinaryAuthorization using the # project's singleton policy. This is equivalent to setting the # enabled boolean to true. PROJECT_SINGLETON_POLICY_ENFORCE = 2 end end |