Class: Google::Cloud::Container::V1::BlueGreenSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Settings for blue-green upgrade.

Defined Under Namespace

Classes: AutoscaledRolloutPolicy, StandardRolloutPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaled_rollout_policy::Google::Cloud::Container::V1::BlueGreenSettings::AutoscaledRolloutPolicy

Returns Autoscaled policy for cluster autoscaler enabled blue-green upgrade.

Note: The following fields are mutually exclusive: autoscaled_rollout_policy, standard_rollout_policy. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4656

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#node_pool_soak_duration::Google::Protobuf::Duration

Returns Time needed after draining entire blue pool. After this period, blue pool will be cleaned up.

Returns:



4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4656

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#standard_rollout_policy::Google::Cloud::Container::V1::BlueGreenSettings::StandardRolloutPolicy

Returns Standard policy for the blue-green upgrade.

Note: The following fields are mutually exclusive: standard_rollout_policy, autoscaled_rollout_policy. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4656

class BlueGreenSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Standard rollout policy is the default policy for blue-green.
  # @!attribute [rw] batch_percentage
  #   @return [::Float]
  #     Percentage of the blue pool nodes to drain in a batch.
  #     The range of this field should be (0.0, 1.0].
  #
  #     Note: The following fields are mutually exclusive: `batch_percentage`, `batch_node_count`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_node_count
  #   @return [::Integer]
  #     Number of blue nodes to drain in a batch.
  #
  #     Note: The following fields are mutually exclusive: `batch_node_count`, `batch_percentage`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] batch_soak_duration
  #   @return [::Google::Protobuf::Duration]
  #     Soak time after each batch gets drained. Default to zero.
  class StandardRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Autoscaled rollout policy utilizes the cluster autoscaler during
  # blue-green upgrade to scale both the blue and green pools.
  # @!attribute [rw] wait_for_drain_duration
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Time to wait after cordoning the blue pool before draining the
  #     nodes. Defaults to 3 days. The value can be set between 0 and 7 days,
  #     inclusive.
  class AutoscaledRolloutPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end