Class: Google::Cloud::Container::V1::ClusterAutoscaling
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ClusterAutoscaling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/delete node pools based on the current needs.
Defined Under Namespace
Modules: AutopilotGeneralProfile, AutoscalingProfile
Instance Attribute Summary collapse
-
#autopilot_general_profile ⇒ ::Google::Cloud::Container::V1::ClusterAutoscaling::AutopilotGeneralProfile
Autopilot general profile for the cluster, which defines the configuration for the cluster.
-
#autoprovisioning_locations ⇒ ::Array<::String>
The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.
-
#autoprovisioning_node_pool_defaults ⇒ ::Google::Cloud::Container::V1::AutoprovisioningNodePoolDefaults
AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP.
-
#autoscaling_profile ⇒ ::Google::Cloud::Container::V1::ClusterAutoscaling::AutoscalingProfile
Defines autoscaling behaviour.
-
#default_compute_class_config ⇒ ::Google::Cloud::Container::V1::DefaultComputeClassConfig
Default compute class is a configuration for default compute class.
-
#enable_node_autoprovisioning ⇒ ::Boolean
Enables automatic node pool creation and deletion.
-
#resource_limits ⇒ ::Array<::Google::Cloud::Container::V1::ResourceLimit>
Contains global constraints regarding minimum and maximum amount of resources in the cluster.
Instance Attribute Details
#autopilot_general_profile ⇒ ::Google::Cloud::Container::V1::ClusterAutoscaling::AutopilotGeneralProfile
Returns Autopilot general profile for the cluster, which defines the configuration for the cluster.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#autoprovisioning_locations ⇒ ::Array<::String>
Returns The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#autoprovisioning_node_pool_defaults ⇒ ::Google::Cloud::Container::V1::AutoprovisioningNodePoolDefaults
Returns AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#autoscaling_profile ⇒ ::Google::Cloud::Container::V1::ClusterAutoscaling::AutoscalingProfile
Returns Defines autoscaling behaviour.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#default_compute_class_config ⇒ ::Google::Cloud::Container::V1::DefaultComputeClassConfig
Returns Default compute class is a configuration for default compute class.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#enable_node_autoprovisioning ⇒ ::Boolean
Returns Enables automatic node pool creation and deletion.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |
#resource_limits ⇒ ::Array<::Google::Cloud::Container::V1::ResourceLimit>
Returns Contains global constraints regarding minimum and maximum amount of resources in the cluster.
5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5814 class ClusterAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines possible options for autoscaling_profile field. module AutoscalingProfile # No change to autoscaling configuration. PROFILE_UNSPECIFIED = 0 # Prioritize optimizing utilization of resources. OPTIMIZE_UTILIZATION = 1 # Use default (balanced) autoscaling configuration. BALANCED = 2 end # Defines possible options for Autopilot general profile. module AutopilotGeneralProfile # Use default configuration. AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0 # Avoid extra IP consumption. NO_PERFORMANCE = 1 # Use default configuration. NONE = 2 end end |