Class: Google::Cloud::Container::V1::ClusterAutoscaling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/delete node pools based on the current needs.

Defined Under Namespace

Modules: AutopilotGeneralProfile, AutoscalingProfile

Instance Attribute Summary collapse

Instance Attribute Details

#autopilot_general_profile::Google::Cloud::Container::V1::ClusterAutoscaling::AutopilotGeneralProfile

Returns Autopilot general profile for the cluster, which defines the configuration for the cluster.

Returns:



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#autoprovisioning_locations::Array<::String>

Returns The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.

Returns:

  • (::Array<::String>)

    The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#autoprovisioning_node_pool_defaults::Google::Cloud::Container::V1::AutoprovisioningNodePoolDefaults

Returns AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP.

Returns:



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#autoscaling_profile::Google::Cloud::Container::V1::ClusterAutoscaling::AutoscalingProfile

Returns Defines autoscaling behaviour.

Returns:



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#default_compute_class_config::Google::Cloud::Container::V1::DefaultComputeClassConfig

Returns Default compute class is a configuration for default compute class.

Returns:



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#enable_node_autoprovisioning::Boolean

Returns Enables automatic node pool creation and deletion.

Returns:

  • (::Boolean)

    Enables automatic node pool creation and deletion.



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end

#resource_limits::Array<::Google::Cloud::Container::V1::ResourceLimit>

Returns Contains global constraints regarding minimum and maximum amount of resources in the cluster.

Returns:



5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5392

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1
  end
end