Class: Google::Cloud::Container::V1::ConfidentialNodes
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ConfidentialNodes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
Defined Under Namespace
Modules: ConfidentialInstanceType
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1::ConfidentialNodes::ConfidentialInstanceType
Defines the type of technology used by the confidential node.
-
#enabled ⇒ ::Boolean
Whether Confidential Nodes feature is enabled.
Instance Attribute Details
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1::ConfidentialNodes::ConfidentialInstanceType
Returns Defines the type of technology used by the confidential node.
6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6723 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |
#enabled ⇒ ::Boolean
Returns Whether Confidential Nodes feature is enabled.
6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6723 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |