Class: Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
RegistryHostConfig configures the top-level structure for a single containerd registry server's configuration, which represents one hosts.toml file on the node. It will override the same fqdns in PrivateRegistryAccessConfig.
Defined Under Namespace
Modules: HostCapability Classes: CertificateConfig, CertificateConfigPair, HostConfig, RegistryHeader
Instance Attribute Summary collapse
-
#hosts ⇒ ::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostConfig>
HostConfig configures a list of host-specific configurations for the server.
-
#server ⇒ ::String
Defines the host name of the registry server, which will be used to create configuration file as /etc/containerd/hosts.d/
/hosts.toml.
Instance Attribute Details
#hosts ⇒ ::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostConfig>
Returns HostConfig configures a list of host-specific configurations for the server. Each server can have at most 10 host configurations.
1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1454 class RegistryHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CertificateConfig configures certificate for the registry. # @!attribute [rw] gcp_secret_manager_secret_uri # @return [::String] # The URI configures a secret from # [Secret Manager](https://cloud.google.com/secret-manager) # in the format # "projects/$PROJECT_ID/secrets/$SECRET_NAME/versions/$VERSION" for # global secret or # "projects/$PROJECT_ID/locations/$REGION/secrets/$SECRET_NAME/versions/$VERSION" # for regional secret. Version can be fixed (e.g. "2") or "latest" class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CertificateConfigPair configures pairs of certificates, which is used for # client certificate and key pairs under a registry. # @!attribute [rw] cert # @return [::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig] # Cert configures the client certificate. # @!attribute [rw] key # @return [::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig] # Key configures the client private key. Optional. class CertificateConfigPair include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # RegistryHeader configures headers for the registry. # @!attribute [rw] key # @return [::String] # Key configures the header key. # @!attribute [rw] value # @return [::Array<::String>] # Value configures the header value. class RegistryHeader include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # HostConfig configures the registry host under a given Server. # @!attribute [rw] host # @return [::String] # Host configures the registry host/mirror. # It supports fully qualified domain names (FQDN) and IP addresses: # Specifying port is supported. # Wildcards are NOT supported. # Examples: # - my.customdomain.com # - 10.0.1.2:5000 # @!attribute [rw] capabilities # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostCapability>] # Capabilities represent the capabilities of the registry host, # specifying what operations a host is capable of performing. # If not set, containerd enables all capabilities by default. # @!attribute [rw] override_path # @return [::Boolean] # OverridePath is used to indicate the host's API root endpoint is # defined in the URL path rather than by the API specification. This may # be used with non-compliant OCI registries which are missing the /v2 # prefix. # If not set, containerd sets default false. # @!attribute [rw] header # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::RegistryHeader>] # Header configures the registry host headers. # @!attribute [rw] ca # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig>] # CA configures the registry host certificate. # @!attribute [rw] client # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfigPair>] # Client configures the registry host client certificate and key. # @!attribute [rw] dial_timeout # @return [::Google::Protobuf::Duration] # Specifies the maximum duration allowed for a connection attempt to # complete. A shorter timeout helps reduce delays when falling back to # the original registry if the mirror is unreachable. # Maximum allowed value is 180s. If not set, containerd sets default 30s. # The value should be a decimal number of seconds with an `s` suffix. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # HostCapability configures capabilities for the registry host. module HostCapability # UNKNOWN should never be set. HOST_CAPABILITY_UNSPECIFIED = 0 # Pull represents the capability to fetch manifests and blobs by digest. HOST_CAPABILITY_PULL = 1 # Resolve represents the capability to fetch manifests by name. HOST_CAPABILITY_RESOLVE = 2 # Push represents the capability to push blobs and manifests. HOST_CAPABILITY_PUSH = 3 end end |
#server ⇒ ::String
Returns Defines the host name of the registry server, which will be used to
create configuration file as /etc/containerd/hosts.d/
- my.customdomain.com
- 10.0.1.2:5000.
1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1454 class RegistryHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CertificateConfig configures certificate for the registry. # @!attribute [rw] gcp_secret_manager_secret_uri # @return [::String] # The URI configures a secret from # [Secret Manager](https://cloud.google.com/secret-manager) # in the format # "projects/$PROJECT_ID/secrets/$SECRET_NAME/versions/$VERSION" for # global secret or # "projects/$PROJECT_ID/locations/$REGION/secrets/$SECRET_NAME/versions/$VERSION" # for regional secret. Version can be fixed (e.g. "2") or "latest" class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CertificateConfigPair configures pairs of certificates, which is used for # client certificate and key pairs under a registry. # @!attribute [rw] cert # @return [::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig] # Cert configures the client certificate. # @!attribute [rw] key # @return [::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig] # Key configures the client private key. Optional. class CertificateConfigPair include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # RegistryHeader configures headers for the registry. # @!attribute [rw] key # @return [::String] # Key configures the header key. # @!attribute [rw] value # @return [::Array<::String>] # Value configures the header value. class RegistryHeader include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # HostConfig configures the registry host under a given Server. # @!attribute [rw] host # @return [::String] # Host configures the registry host/mirror. # It supports fully qualified domain names (FQDN) and IP addresses: # Specifying port is supported. # Wildcards are NOT supported. # Examples: # - my.customdomain.com # - 10.0.1.2:5000 # @!attribute [rw] capabilities # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostCapability>] # Capabilities represent the capabilities of the registry host, # specifying what operations a host is capable of performing. # If not set, containerd enables all capabilities by default. # @!attribute [rw] override_path # @return [::Boolean] # OverridePath is used to indicate the host's API root endpoint is # defined in the URL path rather than by the API specification. This may # be used with non-compliant OCI registries which are missing the /v2 # prefix. # If not set, containerd sets default false. # @!attribute [rw] header # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::RegistryHeader>] # Header configures the registry host headers. # @!attribute [rw] ca # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig>] # CA configures the registry host certificate. # @!attribute [rw] client # @return [::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfigPair>] # Client configures the registry host client certificate and key. # @!attribute [rw] dial_timeout # @return [::Google::Protobuf::Duration] # Specifies the maximum duration allowed for a connection attempt to # complete. A shorter timeout helps reduce delays when falling back to # the original registry if the mirror is unreachable. # Maximum allowed value is 180s. If not set, containerd sets default 30s. # The value should be a decimal number of seconds with an `s` suffix. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # HostCapability configures capabilities for the registry host. module HostCapability # UNKNOWN should never be set. HOST_CAPABILITY_UNSPECIFIED = 0 # Pull represents the capability to fetch manifests and blobs by digest. HOST_CAPABILITY_PULL = 1 # Resolve represents the capability to fetch manifests by name. HOST_CAPABILITY_RESOLVE = 2 # Push represents the capability to push blobs and manifests. HOST_CAPABILITY_PUSH = 3 end end |