Module: Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostCapability
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
HostCapability configures capabilities for the registry host.
Constant Summary collapse
- HOST_CAPABILITY_UNSPECIFIED =
UNKNOWN should never be set.
0- HOST_CAPABILITY_PULL =
Pull represents the capability to fetch manifests and blobs by digest.
1- HOST_CAPABILITY_RESOLVE =
Resolve represents the capability to fetch manifests by name.
2- HOST_CAPABILITY_PUSH =
Push represents the capability to push blobs and manifests.
3