Class: Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

HostConfig configures the registry host under a given Server.

Instance Attribute Summary collapse

Instance Attribute Details

#ca::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfig>

Returns CA configures the registry host certificate.

Returns:



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#capabilities::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::HostCapability>

Returns Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing. If not set, containerd enables all capabilities by default.

Returns:



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::CertificateConfigPair>

Returns Client configures the registry host client certificate and key.

Returns:



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dial_timeout::Google::Protobuf::Duration

Returns Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix.

Returns:

  • (::Google::Protobuf::Duration)

    Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix.



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#header::Array<::Google::Cloud::Container::V1::ContainerdConfig::RegistryHostConfig::RegistryHeader>

Returns Header configures the registry host headers.

Returns:



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host::String

Returns Host configures the registry host/mirror. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT supported. Examples:

  • my.customdomain.com
  • 10.0.1.2:5000.

Returns:

  • (::String)

    Host configures the registry host/mirror. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT supported. Examples:

    • my.customdomain.com
    • 10.0.1.2:5000


1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#override_path::Boolean

Returns OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non-compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false.

Returns:

  • (::Boolean)

    OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non-compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false.



1536
1537
1538
1539
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1536

class HostConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end