Class: Google::Cloud::Container::V1::ControlPlaneEgress
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ControlPlaneEgress
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ControlPlaneEgress defines the settings needed to enable control plane egress control.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1::ControlPlaneEgress::Mode
Defines the mode of control plane egress.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1::ControlPlaneEgress::Mode
Returns Defines the mode of control plane egress.
3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3012 class ControlPlaneEgress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines the mode of control plane egress. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Control plane has public IP and no restriction on egress. VIA_CONTROL_PLANE = 1 # No public IP on control plane and only internal allowlisted egress. NONE = 2 end end |