Class: Google::Cloud::Container::V1::ControlPlaneEndpointsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Configuration for all of the cluster's control plane endpoints.

Defined Under Namespace

Classes: DNSEndpointConfig, IPEndpointsConfig

Instance Attribute Summary collapse

Instance Attribute Details

#dns_endpoint_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig

Returns DNS endpoint configuration.



7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7742

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ip_endpoints_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::IPEndpointsConfig

Returns IP endpoints configuration.



7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7742

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end