Class: Google::Cloud::Container::V1::ControlPlaneEndpointsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Configuration for all of the cluster's control plane endpoints.

Defined Under Namespace

Classes: DNSEndpointConfig, IPEndpointsConfig

Instance Attribute Summary collapse

Instance Attribute Details

#dns_endpoint_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig

Returns DNS endpoint configuration.



7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7325

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ip_endpoints_config::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::IPEndpointsConfig

Returns IP endpoints configuration.



7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7325

class ControlPlaneEndpointsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the configuration of a DNS endpoint.
  # @!attribute [r] endpoint
  #   @return [::String]
  #     Output only. The cluster's DNS endpoint configuration.
  #     A DNS format address. This is accessible from the public internet.
  #     Ex: uid.us-central1.gke.goog.
  #     Always present, but the behavior may change according to the value of
  #     {::Google::Cloud::Container::V1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}.
  # @!attribute [rw] allow_external_traffic
  #   @return [::Boolean]
  #     Controls whether user traffic is allowed over this endpoint. Note that
  #     Google-managed services may still use the endpoint even if this is false.
  # @!attribute [rw] enable_k8s_tokens_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s token auth is allowed via DNS.
  # @!attribute [rw] enable_k8s_certs_via_dns
  #   @return [::Boolean]
  #     Controls whether the k8s certs auth is allowed via DNS.
  class DNSEndpointConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # IP endpoints configuration.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Controls whether to allow direct IP access.
  # @!attribute [rw] enable_public_endpoint
  #   @return [::Boolean]
  #     Controls whether the control plane allows access through a public IP.
  #     It is invalid to specify both
  #     [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same
  #     time.
  # @!attribute [rw] global_access
  #   @return [::Boolean]
  #     Controls whether the control plane's private endpoint is accessible from
  #     sources in other regions.
  #     It is invalid to specify both
  #     {::Google::Cloud::Container::V1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled}
  #     and this field at the same time.
  # @!attribute [rw] authorized_networks_config
  #   @return [::Google::Cloud::Container::V1::MasterAuthorizedNetworksConfig]
  #     Configuration of authorized networks. If enabled, restricts access to the
  #     control plane based on source IP.
  #     It is invalid to specify both
  #     [Cluster.masterAuthorizedNetworksConfig][] and this field at the same
  #     time.
  # @!attribute [r] public_endpoint
  #   @return [::String]
  #     Output only. The external IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [r] private_endpoint
  #   @return [::String]
  #     Output only. The internal IP address of this cluster's control plane.
  #     Only populated if enabled.
  # @!attribute [rw] private_endpoint_subnetwork
  #   @return [::String]
  #     Subnet to provision the master's private endpoint during cluster
  #     creation. Specified in projects/*/regions/*/subnetworks/* format. It is
  #     invalid to specify both
  #     [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the
  #     same time.
  class IPEndpointsConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end