Class: Google::Cloud::Container::V1::DNSConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::DNSConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
DNSConfig contains the desired set of options for configuring clusterDNS.
Defined Under Namespace
Instance Attribute Summary collapse
-
#additive_vpc_scope_dns_domain ⇒ ::String
Optional.
-
#cluster_dns ⇒ ::Google::Cloud::Container::V1::DNSConfig::Provider
Cluster_dns indicates which in-cluster DNS provider should be used.
-
#cluster_dns_domain ⇒ ::String
Cluster_dns_domain is the suffix used for all cluster service records.
-
#cluster_dns_scope ⇒ ::Google::Cloud::Container::V1::DNSConfig::DNSScope
Cluster_dns_scope indicates the scope of access to cluster DNS records.
Instance Attribute Details
#additive_vpc_scope_dns_domain ⇒ ::String
Returns Optional. The domain used in Additive VPC scope.
6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6715 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns ⇒ ::Google::Cloud::Container::V1::DNSConfig::Provider
Returns cluster_dns indicates which in-cluster DNS provider should be used.
6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6715 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns_domain ⇒ ::String
Returns cluster_dns_domain is the suffix used for all cluster service records.
6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6715 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns_scope ⇒ ::Google::Cloud::Container::V1::DNSConfig::DNSScope
Returns cluster_dns_scope indicates the scope of access to cluster DNS records.
6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6715 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |