Class: Google::Cloud::Container::V1::DNSConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::DNSConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
DNSConfig contains the desired set of options for configuring clusterDNS.
Defined Under Namespace
Instance Attribute Summary collapse
-
#additive_vpc_scope_dns_domain ⇒ ::String
Optional.
-
#cluster_dns ⇒ ::Google::Cloud::Container::V1::DNSConfig::Provider
Cluster_dns indicates which in-cluster DNS provider should be used.
-
#cluster_dns_domain ⇒ ::String
Cluster_dns_domain is the suffix used for all cluster service records.
-
#cluster_dns_scope ⇒ ::Google::Cloud::Container::V1::DNSConfig::DNSScope
Cluster_dns_scope indicates the scope of access to cluster DNS records.
Instance Attribute Details
#additive_vpc_scope_dns_domain ⇒ ::String
Returns Optional. The domain used in Additive VPC scope.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6661 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns ⇒ ::Google::Cloud::Container::V1::DNSConfig::Provider
Returns cluster_dns indicates which in-cluster DNS provider should be used.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6661 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns_domain ⇒ ::String
Returns cluster_dns_domain is the suffix used for all cluster service records.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6661 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |
#cluster_dns_scope ⇒ ::Google::Cloud::Container::V1::DNSConfig::DNSScope
Returns cluster_dns_scope indicates the scope of access to cluster DNS records.
6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6661 class DNSConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Provider lists the various in-cluster DNS providers. module Provider # Default value PROVIDER_UNSPECIFIED = 0 # Use GKE default DNS provider(kube-dns) for DNS resolution. PLATFORM_DEFAULT = 1 # Use CloudDNS for DNS resolution. CLOUD_DNS = 2 # Use KubeDNS for DNS resolution. KUBE_DNS = 3 end # DNSScope lists the various scopes of access to cluster DNS records. module DNSScope # Default value, will be inferred as cluster scope. DNS_SCOPE_UNSPECIFIED = 0 # DNS records are accessible from within the cluster. CLUSTER_SCOPE = 1 # DNS records are accessible from within the VPC. VPC_SCOPE = 2 end end |