Class: Google::Cloud::Container::V1::DNSConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

DNSConfig contains the desired set of options for configuring clusterDNS.

Defined Under Namespace

Modules: DNSScope, Provider

Instance Attribute Summary collapse

Instance Attribute Details

#additive_vpc_scope_dns_domain::String

Returns Optional. The domain used in Additive VPC scope.

Returns:

  • (::String)

    Optional. The domain used in Additive VPC scope.



6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6287

class DNSConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Provider lists the various in-cluster DNS providers.
  module Provider
    # Default value
    PROVIDER_UNSPECIFIED = 0

    # Use GKE default DNS provider(kube-dns) for DNS resolution.
    PLATFORM_DEFAULT = 1

    # Use CloudDNS for DNS resolution.
    CLOUD_DNS = 2

    # Use KubeDNS for DNS resolution.
    KUBE_DNS = 3
  end

  # DNSScope lists the various scopes of access to cluster DNS records.
  module DNSScope
    # Default value, will be inferred as cluster scope.
    DNS_SCOPE_UNSPECIFIED = 0

    # DNS records are accessible from within the cluster.
    CLUSTER_SCOPE = 1

    # DNS records are accessible from within the VPC.
    VPC_SCOPE = 2
  end
end

#cluster_dns::Google::Cloud::Container::V1::DNSConfig::Provider

Returns cluster_dns indicates which in-cluster DNS provider should be used.

Returns:



6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6287

class DNSConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Provider lists the various in-cluster DNS providers.
  module Provider
    # Default value
    PROVIDER_UNSPECIFIED = 0

    # Use GKE default DNS provider(kube-dns) for DNS resolution.
    PLATFORM_DEFAULT = 1

    # Use CloudDNS for DNS resolution.
    CLOUD_DNS = 2

    # Use KubeDNS for DNS resolution.
    KUBE_DNS = 3
  end

  # DNSScope lists the various scopes of access to cluster DNS records.
  module DNSScope
    # Default value, will be inferred as cluster scope.
    DNS_SCOPE_UNSPECIFIED = 0

    # DNS records are accessible from within the cluster.
    CLUSTER_SCOPE = 1

    # DNS records are accessible from within the VPC.
    VPC_SCOPE = 2
  end
end

#cluster_dns_domain::String

Returns cluster_dns_domain is the suffix used for all cluster service records.

Returns:

  • (::String)

    cluster_dns_domain is the suffix used for all cluster service records.



6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6287

class DNSConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Provider lists the various in-cluster DNS providers.
  module Provider
    # Default value
    PROVIDER_UNSPECIFIED = 0

    # Use GKE default DNS provider(kube-dns) for DNS resolution.
    PLATFORM_DEFAULT = 1

    # Use CloudDNS for DNS resolution.
    CLOUD_DNS = 2

    # Use KubeDNS for DNS resolution.
    KUBE_DNS = 3
  end

  # DNSScope lists the various scopes of access to cluster DNS records.
  module DNSScope
    # Default value, will be inferred as cluster scope.
    DNS_SCOPE_UNSPECIFIED = 0

    # DNS records are accessible from within the cluster.
    CLUSTER_SCOPE = 1

    # DNS records are accessible from within the VPC.
    VPC_SCOPE = 2
  end
end

#cluster_dns_scope::Google::Cloud::Container::V1::DNSConfig::DNSScope

Returns cluster_dns_scope indicates the scope of access to cluster DNS records.

Returns:



6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6287

class DNSConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Provider lists the various in-cluster DNS providers.
  module Provider
    # Default value
    PROVIDER_UNSPECIFIED = 0

    # Use GKE default DNS provider(kube-dns) for DNS resolution.
    PLATFORM_DEFAULT = 1

    # Use CloudDNS for DNS resolution.
    CLOUD_DNS = 2

    # Use KubeDNS for DNS resolution.
    KUBE_DNS = 3
  end

  # DNSScope lists the various scopes of access to cluster DNS records.
  module DNSScope
    # Default value, will be inferred as cluster scope.
    DNS_SCOPE_UNSPECIFIED = 0

    # DNS records are accessible from within the cluster.
    CLUSTER_SCOPE = 1

    # DNS records are accessible from within the VPC.
    VPC_SCOPE = 2
  end
end