Class: Google::Cloud::Container::V1::DatabaseEncryption
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::DatabaseEncryption
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration of etcd encryption.
Defined Under Namespace
Modules: CurrentState, State Classes: OperationError
Instance Attribute Summary collapse
-
#current_state ⇒ ::Google::Cloud::Container::V1::DatabaseEncryption::CurrentState
readonly
Output only.
-
#decryption_keys ⇒ ::Array<::String>
readonly
Output only.
-
#key_name ⇒ ::String
Name of CloudKMS key to use for the encryption of secrets in etcd.
-
#last_operation_errors ⇒ ::Array<::Google::Cloud::Container::V1::DatabaseEncryption::OperationError>
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Container::V1::DatabaseEncryption::State
The desired state of etcd encryption.
Instance Attribute Details
#current_state ⇒ ::Google::Cloud::Container::V1::DatabaseEncryption::CurrentState (readonly)
Returns Output only. The current state of etcd encryption.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6385 class DatabaseEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # OperationError records errors seen from CloudKMS keys # encountered during updates to DatabaseEncryption configuration. # @!attribute [rw] key_name # @return [::String] # CloudKMS key resource that had the error. # @!attribute [rw] error_message # @return [::String] # Description of the error seen during the operation. # @!attribute [rw] timestamp # @return [::Google::Protobuf::Timestamp] # Time when the CloudKMS error was seen. class OperationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of etcd encryption. module State # Should never be set UNKNOWN = 0 # Secrets in etcd are encrypted. ENCRYPTED = 1 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. DECRYPTED = 2 end # Current State of etcd encryption. module CurrentState # Should never be set CURRENT_STATE_UNSPECIFIED = 0 # Secrets in etcd are encrypted. CURRENT_STATE_ENCRYPTED = 7 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. CURRENT_STATE_DECRYPTED = 2 # Encryption (or re-encryption with a different CloudKMS key) # of Secrets is in progress. CURRENT_STATE_ENCRYPTION_PENDING = 3 # Encryption (or re-encryption with a different CloudKMS key) of Secrets in # etcd encountered an error. CURRENT_STATE_ENCRYPTION_ERROR = 4 # De-crypting Secrets to plain text in etcd is in progress. CURRENT_STATE_DECRYPTION_PENDING = 5 # De-crypting Secrets to plain text in etcd encountered an error. CURRENT_STATE_DECRYPTION_ERROR = 6 end end |
#decryption_keys ⇒ ::Array<::String> (readonly)
Returns Output only. Keys in use by the cluster for decrypting
existing objects, in addition to the key in key_name.
Each item is a CloudKMS key resource.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6385 class DatabaseEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # OperationError records errors seen from CloudKMS keys # encountered during updates to DatabaseEncryption configuration. # @!attribute [rw] key_name # @return [::String] # CloudKMS key resource that had the error. # @!attribute [rw] error_message # @return [::String] # Description of the error seen during the operation. # @!attribute [rw] timestamp # @return [::Google::Protobuf::Timestamp] # Time when the CloudKMS error was seen. class OperationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of etcd encryption. module State # Should never be set UNKNOWN = 0 # Secrets in etcd are encrypted. ENCRYPTED = 1 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. DECRYPTED = 2 end # Current State of etcd encryption. module CurrentState # Should never be set CURRENT_STATE_UNSPECIFIED = 0 # Secrets in etcd are encrypted. CURRENT_STATE_ENCRYPTED = 7 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. CURRENT_STATE_DECRYPTED = 2 # Encryption (or re-encryption with a different CloudKMS key) # of Secrets is in progress. CURRENT_STATE_ENCRYPTION_PENDING = 3 # Encryption (or re-encryption with a different CloudKMS key) of Secrets in # etcd encountered an error. CURRENT_STATE_ENCRYPTION_ERROR = 4 # De-crypting Secrets to plain text in etcd is in progress. CURRENT_STATE_DECRYPTION_PENDING = 5 # De-crypting Secrets to plain text in etcd encountered an error. CURRENT_STATE_DECRYPTION_ERROR = 6 end end |
#key_name ⇒ ::String
Returns Name of CloudKMS key to use for the encryption of secrets in etcd. Ex. projects/my-project/locations/global/keyRings/my-ring/cryptoKeys/my-key.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6385 class DatabaseEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # OperationError records errors seen from CloudKMS keys # encountered during updates to DatabaseEncryption configuration. # @!attribute [rw] key_name # @return [::String] # CloudKMS key resource that had the error. # @!attribute [rw] error_message # @return [::String] # Description of the error seen during the operation. # @!attribute [rw] timestamp # @return [::Google::Protobuf::Timestamp] # Time when the CloudKMS error was seen. class OperationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of etcd encryption. module State # Should never be set UNKNOWN = 0 # Secrets in etcd are encrypted. ENCRYPTED = 1 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. DECRYPTED = 2 end # Current State of etcd encryption. module CurrentState # Should never be set CURRENT_STATE_UNSPECIFIED = 0 # Secrets in etcd are encrypted. CURRENT_STATE_ENCRYPTED = 7 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. CURRENT_STATE_DECRYPTED = 2 # Encryption (or re-encryption with a different CloudKMS key) # of Secrets is in progress. CURRENT_STATE_ENCRYPTION_PENDING = 3 # Encryption (or re-encryption with a different CloudKMS key) of Secrets in # etcd encountered an error. CURRENT_STATE_ENCRYPTION_ERROR = 4 # De-crypting Secrets to plain text in etcd is in progress. CURRENT_STATE_DECRYPTION_PENDING = 5 # De-crypting Secrets to plain text in etcd encountered an error. CURRENT_STATE_DECRYPTION_ERROR = 6 end end |
#last_operation_errors ⇒ ::Array<::Google::Cloud::Container::V1::DatabaseEncryption::OperationError> (readonly)
Returns Output only. Records errors seen during DatabaseEncryption update operations.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6385 class DatabaseEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # OperationError records errors seen from CloudKMS keys # encountered during updates to DatabaseEncryption configuration. # @!attribute [rw] key_name # @return [::String] # CloudKMS key resource that had the error. # @!attribute [rw] error_message # @return [::String] # Description of the error seen during the operation. # @!attribute [rw] timestamp # @return [::Google::Protobuf::Timestamp] # Time when the CloudKMS error was seen. class OperationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of etcd encryption. module State # Should never be set UNKNOWN = 0 # Secrets in etcd are encrypted. ENCRYPTED = 1 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. DECRYPTED = 2 end # Current State of etcd encryption. module CurrentState # Should never be set CURRENT_STATE_UNSPECIFIED = 0 # Secrets in etcd are encrypted. CURRENT_STATE_ENCRYPTED = 7 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. CURRENT_STATE_DECRYPTED = 2 # Encryption (or re-encryption with a different CloudKMS key) # of Secrets is in progress. CURRENT_STATE_ENCRYPTION_PENDING = 3 # Encryption (or re-encryption with a different CloudKMS key) of Secrets in # etcd encountered an error. CURRENT_STATE_ENCRYPTION_ERROR = 4 # De-crypting Secrets to plain text in etcd is in progress. CURRENT_STATE_DECRYPTION_PENDING = 5 # De-crypting Secrets to plain text in etcd encountered an error. CURRENT_STATE_DECRYPTION_ERROR = 6 end end |
#state ⇒ ::Google::Cloud::Container::V1::DatabaseEncryption::State
Returns The desired state of etcd encryption.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6385 class DatabaseEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # OperationError records errors seen from CloudKMS keys # encountered during updates to DatabaseEncryption configuration. # @!attribute [rw] key_name # @return [::String] # CloudKMS key resource that had the error. # @!attribute [rw] error_message # @return [::String] # Description of the error seen during the operation. # @!attribute [rw] timestamp # @return [::Google::Protobuf::Timestamp] # Time when the CloudKMS error was seen. class OperationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of etcd encryption. module State # Should never be set UNKNOWN = 0 # Secrets in etcd are encrypted. ENCRYPTED = 1 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. DECRYPTED = 2 end # Current State of etcd encryption. module CurrentState # Should never be set CURRENT_STATE_UNSPECIFIED = 0 # Secrets in etcd are encrypted. CURRENT_STATE_ENCRYPTED = 7 # Secrets in etcd are stored in plain text (at etcd level) - this is # unrelated to Compute Engine level full disk encryption. CURRENT_STATE_DECRYPTED = 2 # Encryption (or re-encryption with a different CloudKMS key) # of Secrets is in progress. CURRENT_STATE_ENCRYPTION_PENDING = 3 # Encryption (or re-encryption with a different CloudKMS key) of Secrets in # etcd encountered an error. CURRENT_STATE_ENCRYPTION_ERROR = 4 # De-crypting Secrets to plain text in etcd is in progress. CURRENT_STATE_DECRYPTION_PENDING = 5 # De-crypting Secrets to plain text in etcd encountered an error. CURRENT_STATE_DECRYPTION_ERROR = 6 end end |