Class: Google::Cloud::Container::V1::DisruptionEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::DisruptionEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
Defined Under Namespace
Modules: DisruptionType Classes: PdbBlockedPod
Instance Attribute Summary collapse
-
#disruption_type ⇒ ::Google::Cloud::Container::V1::DisruptionEvent::DisruptionType
The type of the disruption event.
-
#pdb_blocked_node ⇒ ::String
The node whose drain is blocked by PDB.
-
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1::DisruptionEvent::PdbBlockedPod>
The pods whose evictions are blocked by PDB.
-
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
The timeout in seconds for which the node drain is blocked by PDB.
Instance Attribute Details
#disruption_type ⇒ ::Google::Cloud::Container::V1::DisruptionEvent::DisruptionType
Returns The type of the disruption event.
7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7268 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_node ⇒ ::String
Returns The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7268 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1::DisruptionEvent::PdbBlockedPod>
Returns The pods whose evictions are blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7268 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
Returns The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION.
7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7268 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |