Class: Google::Cloud::Container::V1::DisruptionEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

DisruptionEvent is a notification sent to customers about the disruption event of a resource.

Defined Under Namespace

Modules: DisruptionType Classes: PdbBlockedPod

Instance Attribute Summary collapse

Instance Attribute Details

#disruption_type::Google::Cloud::Container::V1::DisruptionEvent::DisruptionType

Returns The type of the disruption event.

Returns:



6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6875

class DisruptionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The namespace/name of the pod whose eviction is blocked by PDB.
  # @!attribute [rw] namespace
  #   @return [::String]
  #     The namespace of the pod.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the pod.
  class PdbBlockedPod
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the disruption event.
  module DisruptionType
    # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified.
    DISRUPTION_TYPE_UNSPECIFIED = 0

    # POD_NOT_ENOUGH_PDB indicates there are still running pods
    # on the node during node drain because their evictions are blocked by PDB.
    POD_NOT_ENOUGH_PDB = 1

    # POD_PDB_VIOLATION indicates that there are force pod
    # evictions during node drain which violate the PDB.
    POD_PDB_VIOLATION = 2
  end
end

#pdb_blocked_node::String

Returns The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.

Returns:

  • (::String)

    The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.



6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6875

class DisruptionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The namespace/name of the pod whose eviction is blocked by PDB.
  # @!attribute [rw] namespace
  #   @return [::String]
  #     The namespace of the pod.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the pod.
  class PdbBlockedPod
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the disruption event.
  module DisruptionType
    # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified.
    DISRUPTION_TYPE_UNSPECIFIED = 0

    # POD_NOT_ENOUGH_PDB indicates there are still running pods
    # on the node during node drain because their evictions are blocked by PDB.
    POD_NOT_ENOUGH_PDB = 1

    # POD_PDB_VIOLATION indicates that there are force pod
    # evictions during node drain which violate the PDB.
    POD_PDB_VIOLATION = 2
  end
end

#pdb_blocked_pod::Array<::Google::Cloud::Container::V1::DisruptionEvent::PdbBlockedPod>

Returns The pods whose evictions are blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.

Returns:



6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6875

class DisruptionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The namespace/name of the pod whose eviction is blocked by PDB.
  # @!attribute [rw] namespace
  #   @return [::String]
  #     The namespace of the pod.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the pod.
  class PdbBlockedPod
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the disruption event.
  module DisruptionType
    # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified.
    DISRUPTION_TYPE_UNSPECIFIED = 0

    # POD_NOT_ENOUGH_PDB indicates there are still running pods
    # on the node during node drain because their evictions are blocked by PDB.
    POD_NOT_ENOUGH_PDB = 1

    # POD_PDB_VIOLATION indicates that there are force pod
    # evictions during node drain which violate the PDB.
    POD_PDB_VIOLATION = 2
  end
end

#pdb_violation_timeout::Google::Protobuf::Duration

Returns The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION.

Returns:

  • (::Google::Protobuf::Duration)

    The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION.



6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6875

class DisruptionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The namespace/name of the pod whose eviction is blocked by PDB.
  # @!attribute [rw] namespace
  #   @return [::String]
  #     The namespace of the pod.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the pod.
  class PdbBlockedPod
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the disruption event.
  module DisruptionType
    # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified.
    DISRUPTION_TYPE_UNSPECIFIED = 0

    # POD_NOT_ENOUGH_PDB indicates there are still running pods
    # on the node during node drain because their evictions are blocked by PDB.
    POD_NOT_ENOUGH_PDB = 1

    # POD_PDB_VIOLATION indicates that there are force pod
    # evictions during node drain which violate the PDB.
    POD_PDB_VIOLATION = 2
  end
end