Class: Google::Cloud::Container::V1::GkeAutoUpgradeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::GkeAutoUpgradeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
Defined Under Namespace
Modules: PatchMode
Instance Attribute Summary collapse
-
#patch_mode ⇒ ::Google::Cloud::Container::V1::GkeAutoUpgradeConfig::PatchMode
PatchMode specifies how auto upgrade patch builds should be selected.
Instance Attribute Details
#patch_mode ⇒ ::Google::Cloud::Container::V1::GkeAutoUpgradeConfig::PatchMode
Returns PatchMode specifies how auto upgrade patch builds should be selected.
8239 8240 8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 8252 8253 8254 8255 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8239 class GkeAutoUpgradeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PatchMode specifies how auto upgrade patch builds should be # selected. module PatchMode # PATCH_MODE_UNSPECIFIED defaults to using the upgrade target from the # channel's patch upgrade targets as the upgrade target for the # version. PATCH_MODE_UNSPECIFIED = 0 # ACCELERATED denotes that the latest patch build in the channel should be # used as the upgrade target for the version. ACCELERATED = 1 end end |