Class: Google::Cloud::Container::V1::GkeAutoUpgradeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::GkeAutoUpgradeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
Defined Under Namespace
Modules: PatchMode
Instance Attribute Summary collapse
-
#patch_mode ⇒ ::Google::Cloud::Container::V1::GkeAutoUpgradeConfig::PatchMode
PatchMode specifies how auto upgrade patch builds should be selected.
Instance Attribute Details
#patch_mode ⇒ ::Google::Cloud::Container::V1::GkeAutoUpgradeConfig::PatchMode
Returns PatchMode specifies how auto upgrade patch builds should be selected.
7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7813 class GkeAutoUpgradeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PatchMode specifies how auto upgrade patch builds should be # selected. module PatchMode # PATCH_MODE_UNSPECIFIED defaults to using the upgrade target from the # channel's patch upgrade targets as the upgrade target for the # version. PATCH_MODE_UNSPECIFIED = 0 # ACCELERATED denotes that the latest patch build in the channel should be # used as the upgrade target for the version. ACCELERATED = 1 end end |