Class: Google::Cloud::Container::V1::LustreCsiDriverConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::LustreCsiDriverConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration for the Lustre CSI driver.
Instance Attribute Summary collapse
-
#enable_legacy_lustre_port ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#enabled ⇒ ::Boolean
Whether the Lustre CSI driver is enabled for this cluster.
Instance Attribute Details
#enable_legacy_lustre_port ⇒ ::Boolean
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns If set to true, the Lustre CSI driver will install Lustre kernel modules using port 6988. This serves as a workaround for a port conflict with the gke-metadata-server. This field is required ONLY under the following conditions:
- The GKE node version is older than 1.33.2-gke.4655000.
- You're connecting to a Lustre instance that has the
'gke-support-enabled' flag.
Deprecated: This flag is no longer required as of GKE node version
1.33.2-gke.4655000, unless you are connecting to a Lustre instance
that has the
gke-support-enabledflag.
2022 2023 2024 2025 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2022 class LustreCsiDriverConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enabled ⇒ ::Boolean
Returns Whether the Lustre CSI driver is enabled for this cluster.
2022 2023 2024 2025 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2022 class LustreCsiDriverConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |