Class: Google::Cloud::Container::V1::MaintenanceExclusionOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Represents the Maintenance exclusion option.

Defined Under Namespace

Modules: EndTimeBehavior, Scope

Instance Attribute Summary collapse

Instance Attribute Details

#end_time_behavior::Google::Cloud::Container::V1::MaintenanceExclusionOptions::EndTimeBehavior

Returns EndTimeBehavior specifies the behavior of the exclusion end time.

Returns:



5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5469

class MaintenanceExclusionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of exclusion.
  module Scope
    # NO_UPGRADES excludes all upgrades, including patch upgrades and minor
    # upgrades across control planes and nodes. This is the default exclusion
    # behavior.
    NO_UPGRADES = 0

    # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only
    # patches are allowed.
    NO_MINOR_UPGRADES = 1

    # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster,
    # and also exclude all node pool upgrades. Only control
    # plane patches are allowed.
    NO_MINOR_OR_NODE_UPGRADES = 2
  end

  # EndTimeBehavior specifies the behavior of the exclusion end time.
  module EndTimeBehavior
    # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed
    # end time.
    END_TIME_BEHAVIOR_UNSPECIFIED = 0

    # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end
    # of the support of the cluster's current version.
    UNTIL_END_OF_SUPPORT = 1
  end
end

#scope::Google::Cloud::Container::V1::MaintenanceExclusionOptions::Scope

Returns Scope specifies the upgrade scope which upgrades are blocked by the exclusion.

Returns:



5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5469

class MaintenanceExclusionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of exclusion.
  module Scope
    # NO_UPGRADES excludes all upgrades, including patch upgrades and minor
    # upgrades across control planes and nodes. This is the default exclusion
    # behavior.
    NO_UPGRADES = 0

    # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only
    # patches are allowed.
    NO_MINOR_UPGRADES = 1

    # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster,
    # and also exclude all node pool upgrades. Only control
    # plane patches are allowed.
    NO_MINOR_OR_NODE_UPGRADES = 2
  end

  # EndTimeBehavior specifies the behavior of the exclusion end time.
  module EndTimeBehavior
    # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed
    # end time.
    END_TIME_BEHAVIOR_UNSPECIFIED = 0

    # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end
    # of the support of the cluster's current version.
    UNTIL_END_OF_SUPPORT = 1
  end
end