Class: Google::Cloud::Container::V1::MaintenanceExclusionOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::MaintenanceExclusionOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Represents the Maintenance exclusion option.
Defined Under Namespace
Modules: EndTimeBehavior, Scope
Instance Attribute Summary collapse
-
#end_time_behavior ⇒ ::Google::Cloud::Container::V1::MaintenanceExclusionOptions::EndTimeBehavior
EndTimeBehavior specifies the behavior of the exclusion end time.
-
#scope ⇒ ::Google::Cloud::Container::V1::MaintenanceExclusionOptions::Scope
Scope specifies the upgrade scope which upgrades are blocked by the exclusion.
Instance Attribute Details
#end_time_behavior ⇒ ::Google::Cloud::Container::V1::MaintenanceExclusionOptions::EndTimeBehavior
Returns EndTimeBehavior specifies the behavior of the exclusion end time.
5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5133 class MaintenanceExclusionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope of exclusion. module Scope # NO_UPGRADES excludes all upgrades, including patch upgrades and minor # upgrades across control planes and nodes. This is the default exclusion # behavior. NO_UPGRADES = 0 # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only # patches are allowed. NO_MINOR_UPGRADES = 1 # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster, # and also exclude all node pool upgrades. Only control # plane patches are allowed. NO_MINOR_OR_NODE_UPGRADES = 2 end # EndTimeBehavior specifies the behavior of the exclusion end time. module EndTimeBehavior # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed # end time. END_TIME_BEHAVIOR_UNSPECIFIED = 0 # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end # of the support of the cluster's current version. UNTIL_END_OF_SUPPORT = 1 end end |
#scope ⇒ ::Google::Cloud::Container::V1::MaintenanceExclusionOptions::Scope
Returns Scope specifies the upgrade scope which upgrades are blocked by the exclusion.
5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5133 class MaintenanceExclusionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope of exclusion. module Scope # NO_UPGRADES excludes all upgrades, including patch upgrades and minor # upgrades across control planes and nodes. This is the default exclusion # behavior. NO_UPGRADES = 0 # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only # patches are allowed. NO_MINOR_UPGRADES = 1 # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster, # and also exclude all node pool upgrades. Only control # plane patches are allowed. NO_MINOR_OR_NODE_UPGRADES = 2 end # EndTimeBehavior specifies the behavior of the exclusion end time. module EndTimeBehavior # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed # end time. END_TIME_BEHAVIOR_UNSPECIFIED = 0 # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end # of the support of the cluster's current version. UNTIL_END_OF_SUPPORT = 1 end end |