Class: Google::Cloud::Container::V1::NetworkTierConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NetworkTierConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
NetworkTierConfig contains network tier information.
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::Google::Cloud::Container::V1::NetworkTierConfig::NetworkTier
Network tier configuration.
Instance Attribute Details
#network_tier ⇒ ::Google::Cloud::Container::V1::NetworkTierConfig::NetworkTier
Returns Network tier configuration.
7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7835 class NetworkTierConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network tier configuration. module NetworkTier # By default, use project-level configuration. When unspecified, the # behavior defaults to NETWORK_TIER_DEFAULT. For cluster updates, this # implies no action (no-op). NETWORK_TIER_UNSPECIFIED = 0 # Default network tier. Use project-level configuration. User can specify # this value, meaning they want to keep the same behaviour as before # cluster level network tier configuration is introduced. This field # ensures backward compatibility for the network tier of cluster resources, # such as node pools and load balancers, for their external IP addresses. NETWORK_TIER_DEFAULT = 1 # Premium network tier. NETWORK_TIER_PREMIUM = 2 # Standard network tier. NETWORK_TIER_STANDARD = 3 end end |