Class: Google::Cloud::Container::V1::NodePool::ExclusionUntilEndOfSupport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Defines the maintenance exclusion for the node pool.

Instance Attribute Summary collapse

Instance Attribute Details

#enabled::Boolean

Returns Optional. Indicates whether the exclusion is enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether the exclusion is enabled.



5265
5266
5267
5268
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5265

class ExclusionUntilEndOfSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The end time of the maintenance exclusion. It is output only. It is the cluster control plane version's end of support time, or end of extended support time when the cluster is on extended support channel.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The end time of the maintenance exclusion. It is output only. It is the cluster control plane version's end of support time, or end of extended support time when the cluster is on extended support channel.



5265
5266
5267
5268
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5265

class ExclusionUntilEndOfSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The start time of the maintenance exclusion. It is output only. It is the exclusion creation time.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The start time of the maintenance exclusion. It is output only. It is the exclusion creation time.



5265
5266
5267
5268
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5265

class ExclusionUntilEndOfSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end