Class: Google::Cloud::Container::V1::NodePool::PlacementPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePool::PlacementPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
PlacementPolicy defines the placement policy used by the node pool.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#policy_name ⇒ ::String
If set, refers to the name of a custom resource policy supplied by the user.
-
#tpu_topology ⇒ ::String
Optional.
-
#type ⇒ ::Google::Cloud::Container::V1::NodePool::PlacementPolicy::Type
The type of placement.
Instance Attribute Details
#policy_name ⇒ ::String
Returns If set, refers to the name of a custom resource policy supplied by the user. The resource policy must be in the same project and region as the node pool. If not found, InvalidArgument error is returned.
5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5208 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#tpu_topology ⇒ ::String
Returns Optional. TPU placement topology for pod slice node pool. https://cloud.google.com/tpu/docs/types-topologies#tpu_topologies.
5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5208 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#type ⇒ ::Google::Cloud::Container::V1::NodePool::PlacementPolicy::Type
Returns The type of placement.
5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5208 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |