Class: Google::Cloud::Container::V1::NodePool::PlacementPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePool::PlacementPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
PlacementPolicy defines the placement policy used by the node pool.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#policy_name ⇒ ::String
If set, refers to the name of a custom resource policy supplied by the user.
-
#tpu_topology ⇒ ::String
Optional.
-
#type ⇒ ::Google::Cloud::Container::V1::NodePool::PlacementPolicy::Type
The type of placement.
Instance Attribute Details
#policy_name ⇒ ::String
Returns If set, refers to the name of a custom resource policy supplied by the user. The resource policy must be in the same project and region as the node pool. If not found, InvalidArgument error is returned.
4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4939 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#tpu_topology ⇒ ::String
Returns Optional. TPU placement topology for pod slice node pool. https://cloud.google.com/tpu/docs/types-topologies#tpu_topologies.
4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4939 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#type ⇒ ::Google::Cloud::Container::V1::NodePool::PlacementPolicy::Type
Returns The type of placement.
4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4939 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |