Class: Google::Cloud::Container::V1::NodePool::UpdateInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePool::UpdateInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
UpdateInfo contains resource (instance groups, etc), status and other intermediate information relevant to a node pool upgrade.
Defined Under Namespace
Classes: BlueGreenInfo
Instance Attribute Summary collapse
-
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Information of a blue-green upgrade.
Instance Attribute Details
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Returns Information of a blue-green upgrade.
5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 5229 5230 5231 5232 5233 5234 5235 5236 5237 5238 5239 5240 5241 5242 5243 5244 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5188 class UpdateInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information relevant to blue-green upgrade. # @!attribute [rw] phase # @return [::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo::Phase] # Current blue-green upgrade phase. # @!attribute [rw] blue_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with blue pool. # @!attribute [rw] green_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with green pool. # @!attribute [rw] blue_pool_deletion_start_time # @return [::String] # Time to start deleting blue pool to complete blue-green upgrade, # in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format. # @!attribute [rw] green_pool_version # @return [::String] # Version of green pool. class BlueGreenInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Phase represents the different stages blue-green upgrade is running in. module Phase # Unspecified phase. PHASE_UNSPECIFIED = 0 # blue-green upgrade has been initiated. UPDATE_STARTED = 1 # Start creating green pool nodes. CREATING_GREEN_POOL = 2 # Start cordoning blue pool nodes. CORDONING_BLUE_POOL = 3 # Start draining blue pool nodes. DRAINING_BLUE_POOL = 4 # Start soaking time after draining entire blue pool. NODE_POOL_SOAKING = 5 # Start deleting blue nodes. DELETING_BLUE_POOL = 6 # Rollback has been initiated. ROLLBACK_STARTED = 7 end end end |