Class: Google::Cloud::Container::V1::NodePool::UpdateInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePool::UpdateInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
UpdateInfo contains resource (instance groups, etc), status and other intermediate information relevant to a node pool upgrade.
Defined Under Namespace
Classes: BlueGreenInfo
Instance Attribute Summary collapse
-
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Information of a blue-green upgrade.
Instance Attribute Details
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Returns Information of a blue-green upgrade.
5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5137 class UpdateInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information relevant to blue-green upgrade. # @!attribute [rw] phase # @return [::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo::Phase] # Current blue-green upgrade phase. # @!attribute [rw] blue_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with blue pool. # @!attribute [rw] green_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with green pool. # @!attribute [rw] blue_pool_deletion_start_time # @return [::String] # Time to start deleting blue pool to complete blue-green upgrade, # in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format. # @!attribute [rw] green_pool_version # @return [::String] # Version of green pool. class BlueGreenInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Phase represents the different stages blue-green upgrade is running in. module Phase # Unspecified phase. PHASE_UNSPECIFIED = 0 # blue-green upgrade has been initiated. UPDATE_STARTED = 1 # Start creating green pool nodes. CREATING_GREEN_POOL = 2 # Start cordoning blue pool nodes. CORDONING_BLUE_POOL = 3 # Start draining blue pool nodes. DRAINING_BLUE_POOL = 4 # Start soaking time after draining entire blue pool. NODE_POOL_SOAKING = 5 # Start deleting blue nodes. DELETING_BLUE_POOL = 6 # Rollback has been initiated. ROLLBACK_STARTED = 7 end end end |