Class: Google::Cloud::Container::V1::NodePool::UpdateInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePool::UpdateInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
UpdateInfo contains resource (instance groups, etc), status and other intermediate information relevant to a node pool upgrade.
Defined Under Namespace
Classes: BlueGreenInfo
Instance Attribute Summary collapse
-
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Information of a blue-green upgrade.
Instance Attribute Details
#blue_green_info ⇒ ::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo
Returns Information of a blue-green upgrade.
4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 4919 4920 4921 4922 4923 4924 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4868 class UpdateInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information relevant to blue-green upgrade. # @!attribute [rw] phase # @return [::Google::Cloud::Container::V1::NodePool::UpdateInfo::BlueGreenInfo::Phase] # Current blue-green upgrade phase. # @!attribute [rw] blue_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with blue pool. # @!attribute [rw] green_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with green pool. # @!attribute [rw] blue_pool_deletion_start_time # @return [::String] # Time to start deleting blue pool to complete blue-green upgrade, # in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format. # @!attribute [rw] green_pool_version # @return [::String] # Version of green pool. class BlueGreenInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Phase represents the different stages blue-green upgrade is running in. module Phase # Unspecified phase. PHASE_UNSPECIFIED = 0 # blue-green upgrade has been initiated. UPDATE_STARTED = 1 # Start creating green pool nodes. CREATING_GREEN_POOL = 2 # Start cordoning blue pool nodes. CORDONING_BLUE_POOL = 3 # Start draining blue pool nodes. DRAINING_BLUE_POOL = 4 # Start soaking time after draining entire blue pool. NODE_POOL_SOAKING = 5 # Start deleting blue nodes. DELETING_BLUE_POOL = 6 # Rollback has been initiated. ROLLBACK_STARTED = 7 end end end |