Class: Google::Cloud::Container::V1::NodePoolUpgradeInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NodePoolUpgradeInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
NodePoolUpgradeInfo contains the upgrade information of a node pool.
Defined Under Namespace
Modules: AutoUpgradePausedReason, AutoUpgradeStatus
Instance Attribute Summary collapse
-
#auto_upgrade_status ⇒ ::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradeStatus>
The auto upgrade status.
-
#end_of_extended_support_timestamp ⇒ ::String
The node pool's current minor version's end of extended support timestamp.
-
#end_of_standard_support_timestamp ⇒ ::String
The node pool's current minor version's end of standard support timestamp.
-
#minor_target_version ⇒ ::String
Minor_target_version indicates the target version for minor upgrade.
-
#patch_target_version ⇒ ::String
Patch_target_version indicates the target version for patch upgrade.
-
#paused_reason ⇒ ::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradePausedReason>
The auto upgrade paused reason.
-
#upgrade_details ⇒ ::Array<::Google::Cloud::Container::V1::UpgradeDetails>
The list of past auto upgrades.
Instance Attribute Details
#auto_upgrade_status ⇒ ::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradeStatus>
Returns The auto upgrade status.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#end_of_extended_support_timestamp ⇒ ::String
Returns The node pool's current minor version's end of extended support timestamp.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#end_of_standard_support_timestamp ⇒ ::String
Returns The node pool's current minor version's end of standard support timestamp.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#minor_target_version ⇒ ::String
Returns minor_target_version indicates the target version for minor upgrade.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#patch_target_version ⇒ ::String
Returns patch_target_version indicates the target version for patch upgrade.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#paused_reason ⇒ ::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradePausedReason>
Returns The auto upgrade paused reason.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |
#upgrade_details ⇒ ::Array<::Google::Cloud::Container::V1::UpgradeDetails>
Returns The list of past auto upgrades.
8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 8257 class NodePoolUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 2 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 3 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 2 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 4 end end |