Class: Google::Cloud::Container::V1::NodePoolUpgradeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

NodePoolUpgradeInfo contains the upgrade information of a nodepool.

Defined Under Namespace

Modules: AutoUpgradePausedReason, AutoUpgradeStatus

Instance Attribute Summary collapse

Instance Attribute Details

#auto_upgrade_status::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradeStatus>

Returns The auto upgrade status.

Returns:



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#end_of_extended_support_timestamp::String

Returns The nodepool's current minor version's end of extended support timestamp.

Returns:

  • (::String)

    The nodepool's current minor version's end of extended support timestamp.



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#end_of_standard_support_timestamp::String

Returns The nodepool's current minor version's end of standard support timestamp.

Returns:

  • (::String)

    The nodepool's current minor version's end of standard support timestamp.



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#minor_target_version::String

Returns minor_target_version indicates the target version for minor upgrade.

Returns:

  • (::String)

    minor_target_version indicates the target version for minor upgrade.



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#patch_target_version::String

Returns patch_target_version indicates the target version for patch upgrade.

Returns:

  • (::String)

    patch_target_version indicates the target version for patch upgrade.



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#paused_reason::Array<::Google::Cloud::Container::V1::NodePoolUpgradeInfo::AutoUpgradePausedReason>

Returns The auto upgrade paused reason.

Returns:



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end

#upgrade_details::Array<::Google::Cloud::Container::V1::UpgradeDetails>

Returns The list of past auto upgrades.

Returns:



7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7765

class NodePoolUpgradeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AutoUpgradeStatus indicates the status of auto upgrade.
  module AutoUpgradeStatus
    # UNKNOWN indicates an unknown status.
    UNKNOWN = 0

    # ACTIVE indicates an active status.
    ACTIVE = 1

    # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is
    # paused.
    MINOR_UPGRADE_PAUSED = 2

    # UPGRADE_PAUSED indicates the upgrade is paused.
    UPGRADE_PAUSED = 3
  end

  # AutoUpgradePausedReason indicates the reason for auto upgrade paused
  # status.
  module AutoUpgradePausedReason
    # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason.
    AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0

    # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance
    # window.
    MAINTENANCE_WINDOW = 1

    # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_UPGRADES = 2

    # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a
    # maintenance exclusion with scope NO_MINOR_UPGRADES.
    MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 3

    # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config.
    SYSTEM_CONFIG = 4
  end
end