Class: Google::Cloud::Container::V1::NotificationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::NotificationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
NotificationConfig is the configuration of notifications.
Defined Under Namespace
Modules: EventType Classes: Filter, PubSub
Instance Attribute Summary collapse
-
#pubsub ⇒ ::Google::Cloud::Container::V1::NotificationConfig::PubSub
Notification config for Pub/Sub.
Instance Attribute Details
#pubsub ⇒ ::Google::Cloud::Container::V1::NotificationConfig::PubSub
Returns Notification config for Pub/Sub.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 7103 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7051 class NotificationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pub/Sub specific notification config. # @!attribute [rw] enabled # @return [::Boolean] # Enable notifications for Pub/Sub. # @!attribute [rw] topic # @return [::String] # The desired Pub/Sub topic to which notifications will be # sent by GKE. Format is `projects/{project}/topics/{topic}`. # @!attribute [rw] filter # @return [::Google::Cloud::Container::V1::NotificationConfig::Filter] # Allows filtering to one or more specific event types. If no filter is # specified, or if a filter is specified with no event types, all event # types will be sent class PubSub include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Allows filtering to one or more specific event types. If event types are # present, those and only those event types will be transmitted to the # cluster. Other types will be skipped. If no filter is specified, or no # event types are present, all event types will be sent # @!attribute [rw] event_type # @return [::Array<::Google::Cloud::Container::V1::NotificationConfig::EventType>] # Event types to allowlist. class Filter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Types of notifications currently supported. Can be used to filter what # notifications are sent. module EventType # Not set, will be ignored. EVENT_TYPE_UNSPECIFIED = 0 # Corresponds with UpgradeAvailableEvent. UPGRADE_AVAILABLE_EVENT = 1 # Corresponds with UpgradeEvent. UPGRADE_EVENT = 2 # Corresponds with SecurityBulletinEvent. SECURITY_BULLETIN_EVENT = 3 # Corresponds with UpgradeInfoEvent. UPGRADE_INFO_EVENT = 4 end end |