Class: Google::Cloud::Container::V1::NotificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

NotificationConfig is the configuration of notifications.

Defined Under Namespace

Modules: EventType Classes: Filter, PubSub

Instance Attribute Summary collapse

Instance Attribute Details

#pubsub::Google::Cloud::Container::V1::NotificationConfig::PubSub

Returns Notification config for Pub/Sub.

Returns:



6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
6681
6682
6683
6684
6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6661

class NotificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pub/Sub specific notification config.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enable notifications for Pub/Sub.
  # @!attribute [rw] topic
  #   @return [::String]
  #     The desired Pub/Sub topic to which notifications will be
  #     sent by GKE. Format is `projects/{project}/topics/{topic}`.
  # @!attribute [rw] filter
  #   @return [::Google::Cloud::Container::V1::NotificationConfig::Filter]
  #     Allows filtering to one or more specific event types. If no filter is
  #     specified, or if a filter is specified with no event types, all event
  #     types will be sent
  class PubSub
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Allows filtering to one or more specific event types. If event types are
  # present, those and only those event types will be transmitted to the
  # cluster. Other types will be skipped. If no filter is specified, or no
  # event types are present, all event types will be sent
  # @!attribute [rw] event_type
  #   @return [::Array<::Google::Cloud::Container::V1::NotificationConfig::EventType>]
  #     Event types to allowlist.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of notifications currently supported. Can be used to filter what
  # notifications are sent.
  module EventType
    # Not set, will be ignored.
    EVENT_TYPE_UNSPECIFIED = 0

    # Corresponds with UpgradeAvailableEvent.
    UPGRADE_AVAILABLE_EVENT = 1

    # Corresponds with UpgradeEvent.
    UPGRADE_EVENT = 2

    # Corresponds with SecurityBulletinEvent.
    SECURITY_BULLETIN_EVENT = 3

    # Corresponds with UpgradeInfoEvent.
    UPGRADE_INFO_EVENT = 4
  end
end