Class: Google::Cloud::Container::V1::ReleaseChannel
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ReleaseChannel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
ReleaseChannel indicates which release channel a cluster is subscribed to. Release channels are arranged in order of risk.
When a cluster is subscribed to a release channel, Google maintains both the master version and the node version. Node auto-upgrade defaults to true and cannot be disabled.
Defined Under Namespace
Modules: Channel
Instance Attribute Summary collapse
-
#channel ⇒ ::Google::Cloud::Container::V1::ReleaseChannel::Channel
Channel specifies which release channel the cluster is subscribed to.
Instance Attribute Details
#channel ⇒ ::Google::Cloud::Container::V1::ReleaseChannel::Channel
Returns channel specifies which release channel the cluster is subscribed to.
6587 6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6587 class ReleaseChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values for 'channel'. module Channel # No channel specified. UNSPECIFIED = 0 # RAPID channel is offered on an early access basis for customers who want # to test new releases. # # WARNING: Versions available in the RAPID Channel may be subject to # unresolved issues with no known workaround and are not subject to any # SLAs. RAPID = 1 # Clusters subscribed to REGULAR receive versions that are considered GA # quality. REGULAR is intended for production users who want to take # advantage of new features. REGULAR = 2 # Clusters subscribed to STABLE receive versions that are known to be # stable and reliable in production. STABLE = 3 # Clusters subscribed to EXTENDED receive extended support and availability # for versions which are known to be stable and reliable in production. EXTENDED = 4 end end |