Class: Google::Cloud::Container::V1::ResourceUsageExportConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ResourceUsageExportConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Configuration for exporting cluster resource usages.
Defined Under Namespace
Classes: BigQueryDestination, ConsumptionMeteringConfig
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ ::Google::Cloud::Container::V1::ResourceUsageExportConfig::BigQueryDestination
Configuration to use BigQuery as usage export destination.
-
#consumption_metering_config ⇒ ::Google::Cloud::Container::V1::ResourceUsageExportConfig::ConsumptionMeteringConfig
Configuration to enable resource consumption metering.
-
#enable_network_egress_metering ⇒ ::Boolean
Whether to enable network egress metering for this cluster.
Instance Attribute Details
#bigquery_destination ⇒ ::Google::Cloud::Container::V1::ResourceUsageExportConfig::BigQueryDestination
Returns Configuration to use BigQuery as usage export destination.
6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6956 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#consumption_metering_config ⇒ ::Google::Cloud::Container::V1::ResourceUsageExportConfig::ConsumptionMeteringConfig
Returns Configuration to enable resource consumption metering.
6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6956 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_network_egress_metering ⇒ ::Boolean
Returns Whether to enable network egress metering for this cluster. If enabled, a daemonset will be created in the cluster to meter network egress traffic.
6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6956 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |