Class: Google::Cloud::Container::V1::SecurityPostureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.

Defined Under Namespace

Modules: Mode, VulnerabilityMode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::Container::V1::SecurityPostureConfig::Mode

Returns Sets which mode to use for Security Posture features.

Returns:



3172
3173
3174
3175
3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3172

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Deprecated: Security Posture Enterprise features are no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Deprecated: Basic vulnerability scanning is no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end

#vulnerability_mode::Google::Cloud::Container::V1::SecurityPostureConfig::VulnerabilityMode

Returns Sets which mode to use for vulnerability scanning.

Returns:



3172
3173
3174
3175
3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
# File 'proto_docs/google/container/v1/cluster_service.rb', line 3172

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Deprecated: Security Posture Enterprise features are no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Deprecated: Basic vulnerability scanning is no longer supported.
    # For more details, see
    # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation.
    #
    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end