Class: Google::Cloud::Container::V1::SecurityPostureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.

Defined Under Namespace

Modules: Mode, VulnerabilityMode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::Container::V1::SecurityPostureConfig::Mode

Returns Sets which mode to use for Security Posture features.

Returns:



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2937

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end

#vulnerability_mode::Google::Cloud::Container::V1::SecurityPostureConfig::VulnerabilityMode

Returns Sets which mode to use for vulnerability scanning.

Returns:



2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
# File 'proto_docs/google/container/v1/cluster_service.rb', line 2937

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end