Class: Google::Cloud::Container::V1::ServerConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ServerConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Kubernetes Engine service configuration.
Defined Under Namespace
Classes: ReleaseChannelConfig
Instance Attribute Summary collapse
-
#channels ⇒ ::Array<::Google::Cloud::Container::V1::ServerConfig::ReleaseChannelConfig>
List of release channel configurations.
-
#default_cluster_version ⇒ ::String
Version of Kubernetes the service deploys by default.
-
#default_image_type ⇒ ::String
Default image type.
-
#valid_image_types ⇒ ::Array<::String>
List of valid image types.
-
#valid_master_versions ⇒ ::Array<::String>
List of valid master versions, in descending order.
-
#valid_node_versions ⇒ ::Array<::String>
List of valid node upgrade target versions, in descending order.
Instance Attribute Details
#channels ⇒ ::Array<::Google::Cloud::Container::V1::ServerConfig::ReleaseChannelConfig>
Returns List of release channel configurations.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_cluster_version ⇒ ::String
Returns Version of Kubernetes the service deploys by default.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_image_type ⇒ ::String
Returns Default image type.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_image_types ⇒ ::Array<::String>
Returns List of valid image types.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_master_versions ⇒ ::Array<::String>
Returns List of valid master versions, in descending order.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_node_versions ⇒ ::Array<::String>
Returns List of valid node upgrade target versions, in descending order.
4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4756 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |