Class: Google::Cloud::Container::V1::ServerConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::ServerConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Kubernetes Engine service configuration.
Defined Under Namespace
Classes: ReleaseChannelConfig
Instance Attribute Summary collapse
-
#channels ⇒ ::Array<::Google::Cloud::Container::V1::ServerConfig::ReleaseChannelConfig>
List of release channel configurations.
-
#default_cluster_version ⇒ ::String
Version of Kubernetes the service deploys by default.
-
#default_image_type ⇒ ::String
Default image type.
-
#valid_image_types ⇒ ::Array<::String>
List of valid image types.
-
#valid_master_versions ⇒ ::Array<::String>
List of valid master versions, in descending order.
-
#valid_node_versions ⇒ ::Array<::String>
List of valid node upgrade target versions, in descending order.
Instance Attribute Details
#channels ⇒ ::Array<::Google::Cloud::Container::V1::ServerConfig::ReleaseChannelConfig>
Returns List of release channel configurations.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_cluster_version ⇒ ::String
Returns Version of Kubernetes the service deploys by default.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_image_type ⇒ ::String
Returns Default image type.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_image_types ⇒ ::Array<::String>
Returns List of valid image types.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_master_versions ⇒ ::Array<::String>
Returns List of valid master versions, in descending order.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#valid_node_versions ⇒ ::Array<::String>
Returns List of valid node upgrade target versions, in descending order.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 4490 class ServerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ReleaseChannelConfig exposes configuration for a release channel. # @!attribute [rw] channel # @return [::Google::Cloud::Container::V1::ReleaseChannel::Channel] # The release channel this configuration applies to. # @!attribute [rw] default_version # @return [::String] # The default version for newly created clusters on the channel. # @!attribute [rw] valid_versions # @return [::Array<::String>] # List of valid versions for the channel. # @!attribute [rw] upgrade_target_version # @return [::String] # The auto upgrade target version for clusters on the channel. class ReleaseChannelConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |