Class: Google::Cloud::Container::V1::SoleTenantConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::SoleTenantConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.
Defined Under Namespace
Classes: NodeAffinity
Instance Attribute Summary collapse
-
#min_node_cpus ⇒ ::Integer
Optional.
-
#node_affinities ⇒ ::Array<::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity>
NodeAffinities used to match to a shared sole tenant node group.
Instance Attribute Details
#min_node_cpus ⇒ ::Integer
Returns Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.
1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1479 class SoleTenantConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the NodeAffinity key, values, and affinity operator according to # [shared sole tenant node group # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity). # @!attribute [rw] key # @return [::String] # Key for NodeAffinity. # @!attribute [rw] operator # @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator] # Operator for NodeAffinity. # @!attribute [rw] values # @return [::Array<::String>] # Values for NodeAffinity. class NodeAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operator allows user to specify affinity or anti-affinity for the # given key values. module Operator # Invalid or unspecified affinity operator. OPERATOR_UNSPECIFIED = 0 # Affinity operator. IN = 1 # Anti-affinity operator. NOT_IN = 2 end end end |
#node_affinities ⇒ ::Array<::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity>
Returns NodeAffinities used to match to a shared sole tenant node group.
1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1479 class SoleTenantConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the NodeAffinity key, values, and affinity operator according to # [shared sole tenant node group # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity). # @!attribute [rw] key # @return [::String] # Key for NodeAffinity. # @!attribute [rw] operator # @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator] # Operator for NodeAffinity. # @!attribute [rw] values # @return [::Array<::String>] # Values for NodeAffinity. class NodeAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operator allows user to specify affinity or anti-affinity for the # given key values. module Operator # Invalid or unspecified affinity operator. OPERATOR_UNSPECIFIED = 0 # Affinity operator. IN = 1 # Anti-affinity operator. NOT_IN = 2 end end end |