Class: Google::Cloud::Container::V1::SoleTenantConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.

Defined Under Namespace

Classes: NodeAffinity

Instance Attribute Summary collapse

Instance Attribute Details

#min_node_cpus::Integer

Returns Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.

Returns:

  • (::Integer)

    Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.



1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1458

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end

#node_affinities::Array<::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity>

Returns NodeAffinities used to match to a shared sole tenant node group.

Returns:



1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1458

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end