Class: Google::Cloud::Container::V1::SoleTenantConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.

Defined Under Namespace

Classes: NodeAffinity

Instance Attribute Summary collapse

Instance Attribute Details

#min_node_cpus::Integer

Returns Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.

Returns:

  • (::Integer)

    Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.



1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1330

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end

#node_affinities::Array<::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity>

Returns NodeAffinities used to match to a shared sole tenant node group.

Returns:



1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1330

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end