Class: Google::Cloud::Container::V1::StatusCondition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

StatusCondition describes why a cluster or a node pool has a certain status (e.g., ERROR or DEGRADED).

Defined Under Namespace

Modules: Code

Instance Attribute Summary collapse

Instance Attribute Details

#canonical_code::Google::Rpc::Code

Returns Canonical code of the condition.

Returns:



5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5873

class StatusCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code for each condition
  module Code
    # UNKNOWN indicates a generic condition.
    UNKNOWN = 0

    # GCE_STOCKOUT indicates that Google Compute Engine resources are
    # temporarily unavailable.
    GCE_STOCKOUT = 1

    # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot
    # service account.
    GKE_SERVICE_ACCOUNT_DELETED = 2

    # Google Compute Engine quota was exceeded.
    GCE_QUOTA_EXCEEDED = 3

    # Cluster state was manually changed by an SRE due to a system logic error.
    SET_BY_OPERATOR = 4

    # Unable to perform an encrypt operation against the CloudKMS key used for
    # etcd level encryption.
    CLOUD_KMS_KEY_ERROR = 7

    # Cluster CA is expiring soon.
    CA_EXPIRING = 9

    # Node service account is missing permissions.
    NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10

    # Cloud KMS key version used for etcd level encryption has been destroyed.
    # This is a permanent error.
    CLOUD_KMS_KEY_DESTROYED = 11
  end
end

#code::Google::Cloud::Container::V1::StatusCondition::Code

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Machine-friendly representation of the condition Deprecated. Use canonical_code instead.

Returns:



5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5873

class StatusCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code for each condition
  module Code
    # UNKNOWN indicates a generic condition.
    UNKNOWN = 0

    # GCE_STOCKOUT indicates that Google Compute Engine resources are
    # temporarily unavailable.
    GCE_STOCKOUT = 1

    # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot
    # service account.
    GKE_SERVICE_ACCOUNT_DELETED = 2

    # Google Compute Engine quota was exceeded.
    GCE_QUOTA_EXCEEDED = 3

    # Cluster state was manually changed by an SRE due to a system logic error.
    SET_BY_OPERATOR = 4

    # Unable to perform an encrypt operation against the CloudKMS key used for
    # etcd level encryption.
    CLOUD_KMS_KEY_ERROR = 7

    # Cluster CA is expiring soon.
    CA_EXPIRING = 9

    # Node service account is missing permissions.
    NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10

    # Cloud KMS key version used for etcd level encryption has been destroyed.
    # This is a permanent error.
    CLOUD_KMS_KEY_DESTROYED = 11
  end
end

#message::String

Returns Human-friendly representation of the condition.

Returns:

  • (::String)

    Human-friendly representation of the condition



5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5873

class StatusCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code for each condition
  module Code
    # UNKNOWN indicates a generic condition.
    UNKNOWN = 0

    # GCE_STOCKOUT indicates that Google Compute Engine resources are
    # temporarily unavailable.
    GCE_STOCKOUT = 1

    # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot
    # service account.
    GKE_SERVICE_ACCOUNT_DELETED = 2

    # Google Compute Engine quota was exceeded.
    GCE_QUOTA_EXCEEDED = 3

    # Cluster state was manually changed by an SRE due to a system logic error.
    SET_BY_OPERATOR = 4

    # Unable to perform an encrypt operation against the CloudKMS key used for
    # etcd level encryption.
    CLOUD_KMS_KEY_ERROR = 7

    # Cluster CA is expiring soon.
    CA_EXPIRING = 9

    # Node service account is missing permissions.
    NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10

    # Cloud KMS key version used for etcd level encryption has been destroyed.
    # This is a permanent error.
    CLOUD_KMS_KEY_DESTROYED = 11
  end
end