Class: Google::Cloud::Container::V1::TaintConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::TaintConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
TaintConfig contains the configuration for the taints of the node pool.
Defined Under Namespace
Modules: ArchitectureTaintBehavior
Instance Attribute Summary collapse
Instance Attribute Details
#architecture_taint_behavior ⇒ ::Google::Cloud::Container::V1::TaintConfig::ArchitectureTaintBehavior
Returns Optional. Controls architecture tainting behavior.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 1157 class TaintConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls architecture tainting behavior for a node pool. # New values may be added in the future. module ArchitectureTaintBehavior # Specifies that the behavior is unspecified, defaults to ARM. ARCHITECTURE_TAINT_BEHAVIOR_UNSPECIFIED = 0 # Disables default architecture taints on the node pool. NONE = 1 # Taints all the nodes in the node pool with the default ARM taint. ARM = 2 end end |