Class: Google::Cloud::Container::V1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::UpgradeInfoEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Defined Under Namespace
Instance Attribute Summary collapse
-
#current_version ⇒ ::String
The current version before the upgrade.
-
#description ⇒ ::String
A brief description of the event.
-
#disruption_event ⇒ ::Google::Cloud::Container::V1::DisruptionEvent
The information about the disruption event.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time when the operation ended.
-
#event_type ⇒ ::Google::Cloud::Container::V1::UpgradeInfoEvent::EventType
The type of the event.
-
#extended_support_end_time ⇒ ::Google::Protobuf::Timestamp
The end of extended support timestamp.
-
#operation ⇒ ::String
The operation associated with this upgrade.
-
#resource ⇒ ::String
Optional relative path to the resource.
-
#resource_type ⇒ ::Google::Cloud::Container::V1::UpgradeResourceType
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ ::Google::Protobuf::Timestamp
The end of standard support timestamp.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time when the operation was started.
-
#state ⇒ ::Google::Cloud::Container::V1::UpgradeInfoEvent::State
readonly
Output only.
-
#target_version ⇒ ::String
The target version for the upgrade.
Instance Attribute Details
#current_version ⇒ ::String
Returns The current version before the upgrade.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#description ⇒ ::String
Returns A brief description of the event.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#disruption_event ⇒ ::Google::Cloud::Container::V1::DisruptionEvent
Returns The information about the disruption event. This field is only populated when event_type is DISRUPTION_EVENT.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when the operation ended.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#event_type ⇒ ::Google::Cloud::Container::V1::UpgradeInfoEvent::EventType
Returns The type of the event.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#extended_support_end_time ⇒ ::Google::Protobuf::Timestamp
Returns The end of extended support timestamp.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#operation ⇒ ::String
Returns The operation associated with this upgrade.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#resource ⇒ ::String
Returns Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#resource_type ⇒ ::Google::Cloud::Container::V1::UpgradeResourceType
Returns The resource type associated with the upgrade.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#standard_support_end_time ⇒ ::Google::Protobuf::Timestamp
Returns The end of standard support timestamp.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when the operation was started.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#state ⇒ ::Google::Cloud::Container::V1::UpgradeInfoEvent::State (readonly)
Returns Output only. The state of the upgrade.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |
#target_version ⇒ ::String
Returns The target version for the upgrade.
7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 7256 class UpgradeInfoEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the upgrade. module State # STATE_UNSPECIFIED indicates the state is unspecified. STATE_UNSPECIFIED = 0 # SCHEDULED indicates the upgrade was scheduled. SCHEDULED = 1 # STARTED indicates the upgrade has started. STARTED = 3 # SUCCEEDED indicates the upgrade has completed successfully. SUCCEEDED = 4 # FAILED indicates the upgrade has failed. FAILED = 5 # CANCELED indicates the upgrade has canceled. CANCELED = 6 end # The type of the event. module EventType # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified. EVENT_TYPE_UNSPECIFIED = 0 # END_OF_SUPPORT indicates GKE version reaches end of support, check # standard_support_end_time and extended_support_end_time for more details. END_OF_SUPPORT = 1 # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will # update COS milestone version for new patch versions starting with # the one in the description. COS_MILESTONE_VERSION_UPDATE = 2 # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle. UPGRADE_LIFECYCLE = 3 # DISRUPTION_EVENT indicates the event is about the disruption. DISRUPTION_EVENT = 4 end end |