Class: Google::Cloud::Container::V1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Defined Under Namespace

Modules: EventType, State

Instance Attribute Summary collapse

Instance Attribute Details

#current_version::String

Returns The current version before the upgrade.

Returns:

  • (::String)

    The current version before the upgrade.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#description::String

Returns A brief description of the event.

Returns:

  • (::String)

    A brief description of the event.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#disruption_event::Google::Cloud::Container::V1::DisruptionEvent

Returns The information about the disruption event. This field is only populated when event_type is DISRUPTION_EVENT.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#end_time::Google::Protobuf::Timestamp

Returns The time when the operation ended.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#event_type::Google::Cloud::Container::V1::UpgradeInfoEvent::EventType

Returns The type of the event.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#extended_support_end_time::Google::Protobuf::Timestamp

Returns The end of extended support timestamp.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#operation::String

Returns The operation associated with this upgrade.

Returns:

  • (::String)

    The operation associated with this upgrade.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#resource::String

Returns Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool.

Returns:

  • (::String)

    Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#resource_type::Google::Cloud::Container::V1::UpgradeResourceType

Returns The resource type associated with the upgrade.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#standard_support_end_time::Google::Protobuf::Timestamp

Returns The end of standard support timestamp.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#start_time::Google::Protobuf::Timestamp

Returns The time when the operation was started.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#state::Google::Cloud::Container::V1::UpgradeInfoEvent::State (readonly)

Returns Output only. The state of the upgrade.

Returns:



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end

#target_version::String

Returns The target version for the upgrade.

Returns:

  • (::String)

    The target version for the upgrade.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6812

class UpgradeInfoEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the upgrade.
  module State
    # STATE_UNSPECIFIED indicates the state is unspecified.
    STATE_UNSPECIFIED = 0

    # STARTED indicates the upgrade has started.
    STARTED = 3

    # SUCCEEDED indicates the upgrade has completed successfully.
    SUCCEEDED = 4

    # FAILED indicates the upgrade has failed.
    FAILED = 5

    # CANCELED indicates the upgrade has canceled.
    CANCELED = 6
  end

  # The type of the event.
  module EventType
    # EVENT_TYPE_UNSPECIFIED indicates the event type is unspecified.
    EVENT_TYPE_UNSPECIFIED = 0

    # END_OF_SUPPORT indicates GKE version reaches end of support, check
    # standard_support_end_time and extended_support_end_time for more details.
    END_OF_SUPPORT = 1

    # COS_MILESTONE_VERSION_UPDATE indicates that the COS node image will
    # update COS milestone version for new patch versions starting with
    # the one in the description.
    COS_MILESTONE_VERSION_UPDATE = 2

    # UPGRADE_LIFECYCLE indicates the event is about the upgrade lifecycle.
    UPGRADE_LIFECYCLE = 3

    # DISRUPTION_EVENT indicates the event is about the disruption.
    DISRUPTION_EVENT = 4
  end
end