Class: Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Secondary IP range of a usable subnetwork.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ ::String
The range of IP addresses belonging to this subnetwork secondary range.
-
#range_name ⇒ ::String
The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.
-
#status ⇒ ::Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange::Status
This field is to determine the status of the secondary range programmably.
Instance Attribute Details
#ip_cidr_range ⇒ ::String
Returns The range of IP addresses belonging to this subnetwork secondary range.
6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6944 class UsableSubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status shows the current usage of a secondary IP range. module Status # UNKNOWN is the zero value of the Status enum. It's not a valid status. UNKNOWN = 0 # UNUSED denotes that this range is unclaimed by any cluster. UNUSED = 1 # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for # services. User-managed services range can be shared between clusters # within the same subnetwork. IN_USE_SERVICE = 2 # IN_USE_SHAREABLE_POD denotes this range was created by the network admin # and is currently claimed by a cluster for pods. It can only be used by # other clusters as a pod range. IN_USE_SHAREABLE_POD = 3 # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed # for pods. It cannot be used for other clusters. IN_USE_MANAGED_POD = 4 end end |
#range_name ⇒ ::String
Returns The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.
6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6944 class UsableSubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status shows the current usage of a secondary IP range. module Status # UNKNOWN is the zero value of the Status enum. It's not a valid status. UNKNOWN = 0 # UNUSED denotes that this range is unclaimed by any cluster. UNUSED = 1 # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for # services. User-managed services range can be shared between clusters # within the same subnetwork. IN_USE_SERVICE = 2 # IN_USE_SHAREABLE_POD denotes this range was created by the network admin # and is currently claimed by a cluster for pods. It can only be used by # other clusters as a pod range. IN_USE_SHAREABLE_POD = 3 # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed # for pods. It cannot be used for other clusters. IN_USE_MANAGED_POD = 4 end end |
#status ⇒ ::Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange::Status
Returns This field is to determine the status of the secondary range programmably.
6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6944 class UsableSubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status shows the current usage of a secondary IP range. module Status # UNKNOWN is the zero value of the Status enum. It's not a valid status. UNKNOWN = 0 # UNUSED denotes that this range is unclaimed by any cluster. UNUSED = 1 # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for # services. User-managed services range can be shared between clusters # within the same subnetwork. IN_USE_SERVICE = 2 # IN_USE_SHAREABLE_POD denotes this range was created by the network admin # and is currently claimed by a cluster for pods. It can only be used by # other clusters as a pod range. IN_USE_SHAREABLE_POD = 3 # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed # for pods. It cannot be used for other clusters. IN_USE_MANAGED_POD = 4 end end |