Class: Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Secondary IP range of a usable subnetwork.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#ip_cidr_range::String

Returns The range of IP addresses belonging to this subnetwork secondary range.

Returns:

  • (::String)

    The range of IP addresses belonging to this subnetwork secondary range.



6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6890

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end

#range_name::String

Returns The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.

Returns:

  • (::String)

    The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.



6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6890

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end

#status::Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange::Status

Returns This field is to determine the status of the secondary range programmably.

Returns:



6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6890

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end