Class: Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1/cluster_service.rb

Overview

Secondary IP range of a usable subnetwork.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#ip_cidr_range::String

Returns The range of IP addresses belonging to this subnetwork secondary range.

Returns:

  • (::String)

    The range of IP addresses belonging to this subnetwork secondary range.



6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6500

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end

#range_name::String

Returns The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.

Returns:

  • (::String)

    The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.



6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6500

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end

#status::Google::Cloud::Container::V1::UsableSubnetworkSecondaryRange::Status

Returns This field is to determine the status of the secondary range programmably.

Returns:



6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
# File 'proto_docs/google/container/v1/cluster_service.rb', line 6500

class UsableSubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status shows the current usage of a secondary IP range.
  module Status
    # UNKNOWN is the zero value of the Status enum. It's not a valid status.
    UNKNOWN = 0

    # UNUSED denotes that this range is unclaimed by any cluster.
    UNUSED = 1

    # IN_USE_SERVICE denotes that this range is claimed by cluster(s) for
    # services. User-managed services range can be shared between clusters
    # within the same subnetwork.
    IN_USE_SERVICE = 2

    # IN_USE_SHAREABLE_POD denotes this range was created by the network admin
    # and is currently claimed by a cluster for pods. It can only be used by
    # other clusters as a pod range.
    IN_USE_SHAREABLE_POD = 3

    # IN_USE_MANAGED_POD denotes this range was created by GKE and is claimed
    # for pods. It cannot be used for other clusters.
    IN_USE_MANAGED_POD = 4
  end
end