Class: Google::Cloud::Container::V1::WindowsNodeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::WindowsNodeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.
Defined Under Namespace
Modules: OSVersion
Instance Attribute Summary collapse
-
#os_version ⇒ ::Google::Cloud::Container::V1::WindowsNodeConfig::OSVersion
OSVersion specifies the Windows node config to be used on the node.
Instance Attribute Details
#os_version ⇒ ::Google::Cloud::Container::V1::WindowsNodeConfig::OSVersion
Returns OSVersion specifies the Windows node config to be used on the node.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 387 class WindowsNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible OS version that can be used. module OSVersion # When OSVersion is not specified. OS_VERSION_UNSPECIFIED = 0 # LTSC2019 specifies to use LTSC2019 as the Windows Servercore Base Image. OS_VERSION_LTSC2019 = 1 # LTSC2022 specifies to use LTSC2022 as the Windows Servercore Base Image. OS_VERSION_LTSC2022 = 2 end end |