Class: Google::Cloud::Container::V1::WorkloadMetadataConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1::WorkloadMetadataConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1/cluster_service.rb
Overview
WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1::WorkloadMetadataConfig::Mode
Mode is the configuration for how to expose metadata to workloads running on the node pool.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1::WorkloadMetadataConfig::Mode
Returns Mode is the configuration for how to expose metadata to workloads running on the node pool.
5780 5781 5782 5783 5784 5785 5786 5787 5788 5789 5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 |
# File 'proto_docs/google/container/v1/cluster_service.rb', line 5780 class WorkloadMetadataConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode is the configuration for how to expose metadata to workloads running # on the node. module Mode # Not set. MODE_UNSPECIFIED = 0 # Expose all Compute Engine metadata to pods. GCE_METADATA = 1 # Run the GKE Metadata Server on this node. The GKE Metadata Server exposes # a metadata API to workloads that is compatible with the V1 Compute # Metadata APIs exposed by the Compute Engine and App Engine Metadata # Servers. This feature can only be enabled if Workload Identity is enabled # at the cluster level. GKE_METADATA = 2 end end |